********************************************************************************************************************************************
** This code replicates Figure A.1 in Appendix A.7
********************************************************************************************************************************************


clear
clear matrix
clear mata
set more off
set matsize 600
set type double


** <<IMPORTANT>> Note: Use directory of this code as working directory


** Load publicly available BLS data
use "data/nsa_cpi_disagg_long.dta"


*** Keep only data since 1995
scalar tstart = 205
drop if t<tstart
drop if t>tstart+240

xtset series t

*** Compute inflation
gen pi = ln(cpi)-ln(L3.cpi)
gen pi_all = ln(allcpi)-ln(L3.allcpi)


*** Get rid of series with too few data points (minimum 100 observations)
bysort series: egen nbobs = count(pi)
drop if nbobs<60|nbobs==.
replace pi=0 if pi==.

*** Four categories of the paper
keep if series==79|series==101|series==154|series==175

egen newseries = group(series)



***
*** LOOP: Multiple regressions
***

tempname regresults

postfile `regresults' series startperiod coeff stderr using "reg_results_rolling", replace

egen nbseries = max(newseries)
local nbseries_sc = nbseries[1]


	forvalues i = 1/`nbseries_sc' {
	
	disp(`i')
	
	* Loop over data windows
		scalar wsize = 36
		scalar tend = 445-`=wsize'-1
		quietly{
		forvalues tt = `=tstart'/`=tend' {

			scalar bb=`tt'+`=wsize' 
			disp(`=bb')
			reg pi pi_all if newseries==`i'&t>=`tt'&t<`=bb'
			
			post `regresults' (`i') (`tt') (_b[pi_all]) (_se[pi_all])
			
		}
		}
	}

postclose `regresults'


***
*** Plots
***

clear all
use "reg_results_rolling"

gen date = 1995 + (startperiod-205)/12
gen lowerbound = coeff-1.96*stderr
gen upperbound = coeff+1.96*stderr
twoway (line coeff date if series==1&date<=2010, legend(off) lcolor(black)) (line upperbound date if series==1&date<2010, lpattern(shortdash) lcolor(black)) (line lowerbound date if series==1&date<2010, lpattern(shortdash) lcolor(black)), title("Carbonated drinks") graphregion(fcolor(white) lstyle(none) style(none))  name(g1, replace)
twoway (line coeff date if series==2&date<=2010, legend(off) lcolor(black)) (line upperbound date if series==2&date<2010, lpattern(shortdash) lcolor(black)) (line lowerbound date if series==2&date<2010, lpattern(shortdash) lcolor(black)), title("Beer") graphregion(fcolor(white) lstyle(none) style(none))  name(g2, replace)
twoway (line coeff date if series==3&date<=2010, legend(off) lcolor(black)) (line upperbound date if series==3&date<2010, lpattern(shortdash) lcolor(black)) (line lowerbound date if series==3&date<2010, lpattern(shortdash) lcolor(black)), title("Televisions") graphregion(fcolor(white) lstyle(none) style(none))  name(g3, replace)
twoway (line coeff date if series==4&date<=2010, legend(off) lcolor(black)) (line upperbound date if series==4&date<2010, lpattern(shortdash) lcolor(black)) (line lowerbound date if series==4&date<2010, lpattern(shortdash) lcolor(black)), title("Fees for lessons and instruction") graphregion(fcolor(white) lstyle(none) style(none))  name(g4, replace)

*** Figure A.1
graph combine g1 g2 g3 g4, row(2) col(2) graphregion(fcolor(white) lstyle(none) style(none)) 
