**********
********** Prepare databases for use with Luminata Stevens' pricing regime code
**********
********** NOTE: NEXT STEP IS TO RUN MATLAB CODE pricing_regimes_april2020.m **********************


clear
timer clear
clear matrix
clear mata
set more off
set matsize 6000


** <<IMPORTANT>> Note: Use directory of this code as working directory

foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {

	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		***
		*** Load data
		***
		local infilename ="../data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		compress
		
		gen CAT = "`CAT'"
		gen MKT = "`MKT'"
		display "`MKT'"
		display "`CAT'"
		
		***
		*** 
		***
		
		*** Define relevant price variable
		gen P = REGPRICE

		*** KEEP ONLY NEEDED DATA
		gen P_initial = P
		keep CAT MKT WEEK group_id UNITS P P_initial ITEM DOLLARS IRI_KEY
		drop if P==.

		**** Get rid of prices with fractional cents
		gen temp = P*100
		gen temp1 = round(temp)
		gen temp2 = temp-temp1
		gen temp3 = abs(temp2)
		replace P=. if temp3>0.01
		drop temp*
		
		**** Get rid of small price changes (less than 1%)
		sort group_id WEEK
		gen small=1 if (ln(P[_n])-ln(P[_n-1])<0.01)&(ln(P[_n])-ln(P[_n-1])>-0.01)&(ln(P[_n])-ln(P[_n-1])!=0)
		replace P=. if small==1
		
		drop if P==.
		
		
		****
		**** FILL IN GAPS (very important as IRI scanner data has a lot of missing observations, yet Stevens' procedure is sensitive to this issue)
		****
		by group_id: gen dweek = WEEK-WEEK[_n-1]
				
		* Maximum accepted length of a gap for it to be filled
		local maxgap=4
		
		* Option to fill-in gaps in quote lines  (**IMPORTANT**: only gaps <= maxgap; Can be disabled or modified)
		tsfill
		gsort +group_id -WEEK
		gen dweek_ext = dweek	
		by group_id: replace dweek_ext = dweek_ext[_n-1] if dweek==.
		gen P_nogap = P
		by group_id: replace P=P[_n-1] if P==.&dweek_ext<=`maxgap'
		
		* Fill-in other fields
		by group_id: gen temp1 = IRI_KEY[_N]
		replace IRI_KEY = temp1
		by group_id: gen temp2 = ITEM[_N]
		replace ITEM = temp2
		by group_id: gen temp3 = CAT[_N]
		replace CAT = temp3
		by group_id: gen temp4 = MKT[_N]
		replace MKT = temp4
		
		* Get rid of unwanted observations and variables
		drop if P==.
		drop temp* dweek*
		
		
		**** Check again for small price changes (less than 1%)
		sort group_id WEEK
		drop small
		gen small=1 if (ln(P[_n])-ln(P[_n-1])<0.01)&(ln(P[_n])-ln(P[_n-1])>-0.01)&(ln(P[_n])-ln(P[_n-1])!=0)
		
		bysort group_id: egen any_small=min(small)
		drop if any_small==1
		
		sort group_id WEEK
		*** Identify gaps in quote lines
		by group_id: gen dweek = WEEK-WEEK[_n-1]		
		
		*** Drop quote line if gap of more than x periods
		sort group_id WEEK
		by group_id: egen max_dweek = max(dweek)
		drop if max_dweek>1
		
		*** Drop quote line if ratio of missing observations to total is more than y%
		gen temp1 = 1 if dweek!=1
		by group_id: egen temp2 = count(temp1)
		by group_id: egen nobs_groupid = count(P)
		gen temp3 = (temp2-1)/nobs_groupid
		drop if temp3>0.02
		drop temp*
		
		*** Drop quote line if less than 2 years worth of observations
		drop if nobs_groupid<104

		***
		*** TOTAL SALES
		***
		
		bysort group_id: egen weight = total(DOLLARS)
		
		****************
		*** SAVE DATASET
		****************
		
		local outfilename ="../data/db_pricing_regimes_"+"`CAT'"+"_"+"`MKT'"
		save "`outfilename'", replace
		export delimited "`outfilename'", replace
		
	}		

}
