********************************************************************************************************************************************
** Creates a database that will then be used by zscore_regressions_april2020.do
** 
********************************************************************************************************************************************

clear
clear matrix
clear mata
set more off
set matsize 6000

** <<IMPORTANT>> Note: Use directory of this code as working directory


foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		clear
		
		***
		*** Load data
		***

		local infilename = "../data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		
		
		gen CAT = "`CAT'"
		gen MKT = "`MKT'"
		display "`MKT'"
		display "`CAT'"
		
		xtset group_id WEEK

		
		*** Keep observations considered valid (where regular price is posted price)
		gen valid=0
		replace valid=1 if PRICE_ORIG!=.&PRICE_ORIG==REGPRICE
		
		*** Merge with CPI Food & Beverages data series (intrapolated at weekly frequency)
		drop _merge
		merge m:1 WEEK using "../data/cpi_weekly"

		
		*** Logs
		gen lq = ln(UNITS)
		gen lp = ln(PRICE_ORIG)
		gen lp2 = lp^2
		gen lCPISA = ln(CPISA)
		gen lCPINSA = ln(CPINSA)
		
		xtset group_id WEEK

		*** Run demand regressions
		quietly: areg lq L.lq lp lp2 lCPISA i.WEEK if valid==1, absorb(group_id)
		predict z2 if valid==1, residuals
				
		
		***
		*** Compute z-score
		***
		xtset group_id WEEK
		scalar beta=1-0.0075
		
		* 26 lags
		gen zscore26_2=0 if REGPRICE!=.
		gen zscore26_2_laginfo=0 if REGPRICE!=.
		gen wscore26=0 if REGPRICE!=.
		gen nblags=0
		gen maxlag=0
		gen nbacceptz_2=0
		gen nbacceptzlag_2=0
		gen nbacceptw=0
		gen nblags_wscore=0		
		
		foreach num of numlist 0/26{
			gen lag`num'_accept = 0
			replace lag`num'_accept = 1 if REGPRICE!=.&(REGPRICE==L`num'.REGPRICE)&L`num'.valid==1
			replace wscore26 = wscore26 + beta^(`num')*lag`num'_accept if lag`num'_accept==1&L`num'.z2!=.
			replace nblags_wscore=nblags_wscore+1^(`num') if REGPRICE!=.&L`num'.REGPRICE!=.
			replace nblags = nblags + 1 if L`num'.REGPRICE!=.
			replace maxlag = `num' if L`num'.REGPRICE!=.
			replace zscore26_2 = zscore26_2 + beta^(`num')*lag`num'_accept*L`num'.z2 if lag`num'_accept==1&L`num'.z2!=.
			replace nbacceptz_2 = nbacceptz_2 + (lag`num'_accept==1&L`num'.z2!=.)
			replace zscore26_2_laginfo = zscore26_2_laginfo + beta^(`num')*lag`num'_accept*L`num'.z2 if `num'!=0&lag`num'_accept==1&L`num'.z2!=.
			replace nbacceptzlag_2 = nbacceptzlag_2 + (`num'!=0&lag`num'_accept==1&L`num'.z2!=.)
			
		}
		
		gen zscore26_2_avg = zscore26_2/nbacceptz_2
		gen zscore26_2_laginfo_avg = zscore26_2_laginfo/nbacceptzlag_2
				
		drop *_accept nbaccept*
		
		
		***
		*** Only keep observations and variables useful for subsequent analysis
		
		* Drop variables that are not useful
		drop valid lq lp z Open Clsd PR OU D F SY GE VEND _merge

		* Chain and year indicators to save space
		sort MskdName
		egen chainid = group(MskdName)
		sort YEAR
		egen yearid = group(YEAR)
		drop MskdName YEAR

		
		***
		*** Save data
		***
		local outfilename = "../data/dbase_zscores_april2020_"+"`CAT'"+"_"+"`MKT'"
		save "`outfilename'", replace


	}		

}
