******
**** CREATION OF MAIN DATABASE
****
**** STEP 1: Convert 2001-2011 databases obtained from IRI into Stata format
******

clear
clear matrix
clear mata
set memory 3000m
set more off
set matsize 600


** <<IMPORTANT>> Note: Use directory of this code as working directory


foreach YEAR in Year1 Year2 Year3 Year4 Year5 Year6 Year7 Year8 Year9 Year10 Year11{
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{
		foreach SAMPLE in Sample1 Sample2{
		
			clear all
			clear matrix
			clear mata
			display "`CAT'"
			display "`YEAR'"
			display "`SAMPLE'"
			** Assign WEEKS to YEAR
			if "`YEAR'"=="Year1" local WEEKS 1114_1165
			if "`YEAR'"=="Year2" local WEEKS 1166_1217
			if "`YEAR'"=="Year3" local WEEKS 1218_1269
			if "`YEAR'"=="Year4" local WEEKS 1270_1321
			if "`YEAR'"=="Year5" local WEEKS 1322_1373
			if "`YEAR'"=="Year6" local WEEKS 1374_1426
			if "`YEAR'"=="Year7" local WEEKS 1427_1478
			if "`YEAR'"=="Year8" local WEEKS 1479_1530
			if "`YEAR'"=="Year9" local WEEKS 1531_1582
			if "`YEAR'"=="Year10" local WEEKS 1583_1634
			if "`YEAR'"=="Year11" local WEEKS 1635_1686
			
			** Create file names
			local infilename = "../IRI_dbases_input/"+"`YEAR'"+"/External/"+"`CAT'"+"/"+"`CAT'"+"_groc_"+"`WEEKS'"+"."
			local outfilename = "../IRI_dbases_output/"+"`YEAR'"+"/"+"`CAT'"+"_groc_"+"`YEAR'"
		
			
			** Load original database
			insheet using "`infilename'"
			
			display "file loaded"
			
			** Split sample in 2 to avoid memory problems
			describe, short
			local halfobs=round(r(N)/2)
			local halfobsm1=round(r(N)/2)-1
			if "`SAMPLE'"=="Sample1" drop in `halfobs'/l
			if "`SAMPLE'"=="Sample2" drop in 2/`halfobsm1'

			** Split single string variable into multiple variables
			split v1

			** Drop unused variables
			drop v1
			drop in 1

			*** Rename variables and transform them in numerical values
			rename v11 IRI_KEY
			rename v12 WEEK
			rename v13 SY
			rename v14 GE
			rename v15 VEND
			rename v16 ITEM
			rename v17 UNITS
			rename v18 DOLLARS
			rename v19 F
			rename v110 D
			rename v111 PR

			destring IRI_KEY, replace
			destring WEEK, replace
			destring SY, replace
			destring GE, replace
			destring VEND, replace
			destring ITEM, replace
			destring UNITS, replace
			destring DOLLARS, replace
			destring D, replace
			destring PR, replace
			
			
			*** Generate price variable
			display "Creation of price variable"
			gen PRICE = DOLLARS/UNITS


			*** Save dbase in Stata format
			display "Save database"
			if "`SAMPLE'"=="Sample1" save "`outfilename'", replace
			if "`SAMPLE'"=="Sample2"{
				sort IRI_KEY ITEM WEEK
				append using "`outfilename'"
				save "`outfilename'", replace
				}
			
			save "`outfilename'", replace
		}
	}
}
