******
**** CREATION OF MAIN DATABASE
****
**** STEP 3:
****	- Aggregate yearly databases
****	- Generate price series
****	- Save the "allprices_allyears_wsales_CAT_MKT.dta" datasets that are used in all the analysis do files
******


clear
clear matrix
clear mata
set more off
set matsize 600


** <<IMPORTANT>> Note: Use directory of this code as working directory

foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF{
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{
	
		clear
		
		local outfilename ="../data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		save "`outfilename'", replace emptyok
		
		** Loop through years (2001-2011)
		foreach YEAR in Year1 Year2 Year3 Year4 Year5 Year6 Year7 Year8 Year9 Year10 Year11{

			clear
			display "`MKT'"
			display "`CAT'"
			display "`YEAR'"
			
			*** Load data
			local infilename = "../IRI_dbases_output/"+"`YEAR'"+"/"+"`CAT'"+"_groc_"+"`YEAR'"+"_IRIinfo"
			use "`infilename'"
			
			if "`MKT'"=="PHI" keep if Market_Name=="PHILADELPHIA"
			if "`MKT'"=="NYC" keep if Market_Name=="NEW YORK"
			if "`MKT'"=="LA" keep if Market_Name=="LOS ANGELES"
			if "`MKT'"=="CHI" keep if Market_Name=="CHICAGO"
			if "`MKT'"=="BOS" keep if Market_Name=="BOSTON"
			if "`MKT'"=="HOU" keep if Market_Name=="HOUSTON"
			if "`MKT'"=="SF" keep if Market_Name=="SAN FRANCISCO"			
			if "`MKT'"=="ATL" keep if Market_Name=="ATLANTA"
			if "`MKT'"=="DAL" keep if Market_Name=="DALLAS, TX"


			*** Aggregate all price distribution info into one file
			local outfilename ="../data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
			append using "`outfilename'"
			save "`outfilename'", replace		

			
		}


		**** Create group_id (for eaxch item/store)
		sort IRI_KEY ITEM SY GE VEND WEEK
		egen group_id=group(IRI_KEY ITEM SY GE VEND)


		
		*** Keep original price
		gen PRICE_ORIG = PRICE
		drop PRICE
		
		
		**********
		*** Fill in missing weekly observations with NAs (useful to compute reference price)
		**********
		tsset group_id WEEK
		tsfill
		by group_id: replace IRI_KEY=IRI_KEY[_N]
		by group_id: replace ITEM=ITEM[_N]
		by group_id: replace SY=SY[_N]
		by group_id: replace GE=GE[_N]
		by group_id: replace VEND=VEND[_N]


		*********************************************
		************ GENERATE 7-WEEK REFERENCE PRICES
		*********************************************

		gen REFPRICE = .
				
		* At least 4 out of 7 observations need to be observed
		scalar nperref = 7
		scalar min_WEEK = 1117
		scalar min_obs = 4

		gen PER1 = nperref*floor((WEEK+ floor(nperref/2)-min_WEEK)/nperref)+min_WEEK
		bysort group_id PER1: egen ctPER1=count(PRICE_ORIG)
		by group_id PER1: egen mode_PER1=mode(PRICE_ORIG), maxmode
		
		replace REFPRICE = mode_PER1 if WEEK==PER1&ctPER1>=min_obs
		drop PER1 ctPER1 mode_PER1
		

		forvalues per = 2(1)7 {
			
			gen PER`per' = nperref*floor((WEEK+ floor(nperref/2)- (min_WEEK+`per'-1))/nperref) + (min_WEEK+`per'-1)
			bysort group_id PER`per': egen ctPER`per'=count(PRICE_ORIG)
			by group_id PER`per': egen mode_PER`per'=mode(PRICE_ORIG), maxmode
			
			replace REFPRICE = mode_PER`per' if WEEK==PER`per'&ctPER`per'>=min_obs
			
			drop PER`per' ctPER`per' mode_PER`per'

		}

				
		*** Adjust reference price series to avoid changes that do not 
		*** actually coincide with changes in posted prices
		sort group_id WEEK
		tsset group_id WEEK
		gen ref_temp = REFPRICE
		gen price=PRICE_ORIG
		replace ref_temp=F.ref_temp if (ref_temp!=price)&(price==F.ref_temp)
		replace ref_temp=F.ref_temp if (ref_temp!=price)&(price==F.ref_temp)
		replace ref_temp=F.ref_temp if (ref_temp!=price)&(price==F.ref_temp)
		replace ref_temp=F.ref_temp if (ref_temp!=price)&(price==F.ref_temp)
		replace ref_temp=F.ref_temp if (ref_temp!=price)&(price==F.ref_temp)

		replace ref_temp=L.ref_temp if (ref_temp!=price)&(price==L.ref_temp)
		replace ref_temp=L.ref_temp if (ref_temp!=price)&(price==L.ref_temp)
		replace ref_temp=L.ref_temp if (ref_temp!=price)&(price==L.ref_temp)
		replace ref_temp=L.ref_temp if (ref_temp!=price)&(price==L.ref_temp)

		replace REFPRICE = ref_temp

	
		*********************************************
		************ CREATE PRICE SERIES WHERE V-SHAPED SALES ARE FILTERED OUT
		*********************************************
		*** Generate a regular (no-sales) price series
		gen dp = ln(price/L.price)

		*** Benchmark filter: quite similar to NS
		* 1) The onset of a sale corresponds to a fall in price that is followed within the next three months by a price increase
		* 2) A sale can last at most three months
		* 3) A sale ends as soon as the price remains below the previous period's regular price
		gen price_nosales = price
		by group_id: gen price_nosales_temp=L.price if L.dp>=0 & price<L.price&((F.dp>0&F.dp!=.)|(F2.dp>0&F2.dp!=.)|(F3.dp>0&F3.dp!=.))
		by group_id: replace price_nosales_temp=L.price_nosales_temp if price_nosales_temp==.&dp<=0&L.price<L.price_nosales_temp&price<L.price_nosales_temp&((F.dp>0&F.dp!=.)|(F2.dp>0&F2.dp!=.))
		replace price_nosales=price_nosales_temp if price_nosales_temp!=.
		drop price_nosales_temp
	
		rename price_nosales REGPRICE


		local outfilename ="../data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		save "`outfilename'", replace	
			

	}		

}			


***** A FEW CORRECTIONS TO IRI DATABASE

clear

foreach MKT in DC PHI NYC SD CHI BOS HOU LA{
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{
	

		clear
		clear matrix
		clear mata
		display "`CAT'"
		display "`MKT'"
		
		** Load previously cleaned data
		local infilename = "../data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		
		*** dbase adjustments
		capture confirm variable p 
		if _rc == 0 {
		drop p
		}
		
		capture confirm variable PRICE
		if _rc == 0 {
		drop PRICE
		}
		
		capture confirm variable dp 
		if _rc == 0 {
		drop dp
		}
		
		replace Market_Name = Market_Name[_N]


		save "`infilename'", replace
	
		
	}
}
