********************************************************************************************************************************************
** This code creates two histograms of price changes, for data and simulation (Figure 3, Section 4.2.1)
********************************************************************************************************************************************

clear
clear matrix
clear mata
set more off
set matsize 600

graph set window fontface "Arial"

** <<IMPORTANT>> Note: Use directory of this code as working directory


***
*** dP distribution - model simulations
***

use "data/dp_distribution_sim.dta"

hist dp if dp!=0&(dp<=0.4&dp>=-0.4), bin(20) xtitle("Price change")  xscale(range(-0.4 0.4)) xlabel(-0.4(0.1)0.4) yscale(range(0 6)) ylabel(0(2)6) graphregion(fcolor(white) ilcolor(white) lcolor(white)) title("Model") saving(dpdist_hist_sim, replace)



***
*** dP distribution - Data
***

clear

** STEP 1: Create database of price changes

save "data/dbase_all_dlp_april2020", replace emptyok

foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		***
		*** Load data
		***

		local infilename ="data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		
		gen CAT = "`CAT'"
		gen MKT = "`MKT'"
		display "`MKT'"
		display "`CAT'"
		
		xtset group_id WEEK

		
		*** Define relevant price variable
		gen p = REGPRICE
		drop if p==.
		keep CAT MKT p WEEK group_id
		
		*** Keep only observations for which the price is to the cent
		gen p_dec_100_cent_round = round((p-floor(p))*100-round((p-floor(p))*100),0.001)
		drop if p_dec_100_cent_round~=0
		drop p_*
	
	
		*** Price changes
		gen dlp = ln(p)-ln(L.p)
		drop if dlp==.

		keep CAT MKT dlp
		
		append using "data/dbase_all_dlp_april2020"
		save "data/dbase_all_dlp_april2020", replace

	}		

}


*** STEP 2: Produce histogram

clear all
use "data/dbase_all_dlp_april2020"

drop if dlp==.
hist dlp if dlp!=0&(dlp<=0.4&dlp>=-0.4), bin(20) xtitle("Price change")  xscale(range(-0.4 0.4)) xlabel(-0.4(0.1)0.4) yscale(range(0 6)) ylabel(0(2)6)  graphregion(fcolor(white) ilcolor(white) lcolor(white)) title("Data") saving(dpdist_hist_data, replace)



***
*** Combine two histograms (Figure 3, Section 4.2.1)
***

graph combine dpdist_hist_sim.gph dpdist_hist_data.gph, fysize(50) graphregion(fcolor(white) ilcolor(white) lcolor(white)) rows(1) cols(2)

