********
********  This code is for Table III, panel D, moment #2: Prob modal P revisits old modal P (52w window)
********
		
clear
clear matrix
clear mata
set more off
set matsize 600
set type double

** <<IMPORTANT>> Note: Use directory of this code as working directory

save "./data/dbase_for_price_plan_table3_panelD_moment2_april2020", emptyok replace

foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {
*foreach MKT in HOU LA NYC PHI SF {
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		***
		*** Load data
		***

		local infilename ="data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		display "`MKT'"
		display "`CAT'"
		xtset group_id WEEK


		
		*** Define relevant price variable
		gen p = REGPRICE
		drop if p==.

		
		*** Keep only observations for which the price is to the cent
		gen p_dec_100_cent_round = round((p-floor(p))*100-round((p-floor(p))*100),0.001)
		drop if p_dec_100_cent_round~=0
		drop p_*

		
		*** Unique number of prices within window
		gen w1=ceil((WEEK-1000+1)/13)
		gen w2=ceil((WEEK-1001+1)/13)
		gen w3=ceil((WEEK-1002+1)/13)
		gen w4=ceil((WEEK-1003+1)/13)
		gen w5=ceil((WEEK-1004+1)/13)
		gen w6=ceil((WEEK-1005+1)/13)
		gen w7=ceil((WEEK-1006+1)/13)
		gen w8=ceil((WEEK-1007+1)/13)
		gen w9=ceil((WEEK-1008+1)/13)
		gen w10=ceil((WEEK-1009+1)/13)
		gen w11=ceil((WEEK-1010+1)/13)
		gen w12=ceil((WEEK-1011+1)/13)
		gen w13=ceil((WEEK-1012+1)/13)
		
		
		*** Modal price and unique prices in each window		
		forvalues x=1/13{
			bysort group_id w`x': egen nbobs_w`x'=count(p)
			egen temp_w`x'=group(group_id w`x' p)
			bysort group_id w`x':egen temp2_w`x'=min(temp_w`x')
			bysort group_id w`x':egen temp3_w`x'=max(temp_w`x')
			*gen unique_w`x' = temp3_w`x'-temp2_w`x'+1
			*replace unique_w`x'=. if nbobs_w`x'<13
			bysort group_id w`x':egen modalp_w`x'=mode(p),maxmode
			replace modalp_w`x'=. if nbobs_w`x'<4
		}
		
	*	gen unique=unique_w1
		gen modalp=modalp_w1
		forvalues x=2/13{
			gen temp44 = 1007+(`x'-2)
			gen z=(WEEK-temp44)/13-round((WEEK-temp44)/13)
			replace modalp=modalp_w`x' if z==0
			drop z temp44			
		}
		
		drop w* nbobs_w* temp_w* temp2_w* temp3_w* modalp_w*
		
		
		*** Only keep relevant variables
		keep MKT CAT group_id WEEK p REFPRICE modalp DOLLARS

		
		*** Replace reference price by modal price
		drop REFPRICE
		gen REFPRICE = modalp
			
		
		***
		*** DEFINE LAGS AND LEADS OF PRICE
		***
		
		xtset group_id WEEK
		
		forvalues x = 1/52{
			gen l`x'refp = L`x'.REFPRICE
			gen l`x'p = L`x'.p
		}

		
		egen nlags52_refp = rownonmiss(l1refp l2refp l3refp l4refp l5refp l6refp l7refp l8refp l9refp l10refp l11refp l12refp l13refp l14refp l15refp l16refp l17refp l18refp l19refp l20refp l21refp l22refp l23refp l24refp l25refp l26refp l27refp l28refp l29refp l30refp l31refp l32refp l33refp l34refp l35refp l36refp l37refp l38refp l39refp l40refp l41refp l42refp l43refp l44refp l45refp l46refp l47refp l48refp l49refp l50refp l51refp l52refp)
		egen nlags52_p = rownonmiss(l1p l2p l3p l4p l5p l6p l7p l8p l9p l10p l11p l12p l13p l14p l15p l16p l17p l18p l19p l20p l21p l22p l23p l24p l25p l26p l27p l28p l29p l30p l31p l32p l33p l34p l35p l36p l37p l38p l39p l40p l41p l42p l43p l44p l45p l46p l47p l48p l49p l50p l51p l52p)

		********
		********  Prob that a modal price change revisits old modal price (52w window)
		********
		
		* Identify changes in modal price
		gen dp_modal = 0 if REFPRICE!=.&L.REFPRICE!=.
		replace dp_modal = 1 if dp_modal==0&REFPRICE!=L.REFPRICE
		
		* Check whether the price change lands on an old modal price (last 52 weeks)
		gen dp_to_old_modal = 0 if dp_modal==1
		replace dp_to_old_modal = 1 if dp_to_old_modal==0&nlags52_refp>=47&(REFPRICE==l1refp|REFPRICE==l2refp|REFPRICE==l3refp|REFPRICE==l4refp|REFPRICE==l5refp|REFPRICE==l6refp|REFPRICE==l7refp|REFPRICE==l8refp|REFPRICE==l9refp|REFPRICE==l10refp|REFPRICE==l11refp|REFPRICE==l12refp|REFPRICE==l13refp|REFPRICE==l14refp|REFPRICE==l15refp|REFPRICE==l16refp|REFPRICE==l17refp|REFPRICE==l18refp|REFPRICE==l19refp|REFPRICE==l20refp|REFPRICE==l21refp|REFPRICE==l22refp|REFPRICE==l23refp|REFPRICE==l24refp|REFPRICE==l25refp|REFPRICE==l26refp|REFPRICE==l27refp|REFPRICE==l28refp|REFPRICE==l29refp|REFPRICE==l30refp|REFPRICE==l31refp|REFPRICE==l32refp|REFPRICE==l33refp|REFPRICE==l34refp|REFPRICE==l35refp|REFPRICE==l36refp|REFPRICE==l37refp|REFPRICE==l38refp|REFPRICE==l39refp|REFPRICE==l40refp|REFPRICE==l41refp|REFPRICE==l42refp|REFPRICE==l43refp|REFPRICE==l44refp|REFPRICE==l45refp|REFPRICE==l46refp|REFPRICE==l47refp|REFPRICE==l48refp|REFPRICE==l49refp|REFPRICE==l50refp|REFPRICE==l51refp|REFPRICE==l52refp)
		
		* Check whether the price change lands on an old regular price (last 52 weeks)
		gen dp_to_old_regular = 0 if dp_modal==1
		gen ptemp=p
		replace dp_to_old_regular = 1 if dp_to_old_regular==0&nlags52_p>=47&(ptemp==l1p|ptemp==l2p|ptemp==l3p|ptemp==l4p|ptemp==l5p|ptemp==l6p|ptemp==l7p|ptemp==l8p|ptemp==l9p|ptemp==l10p|ptemp==l11p|ptemp==l12p|ptemp==l13p|ptemp==l14p|ptemp==l15p|ptemp==l16p|ptemp==l17p|ptemp==l18p|ptemp==l19p|ptemp==l20p|ptemp==l21p|ptemp==l22p|ptemp==l23p|ptemp==l24p|ptemp==l25p|ptemp==l26p|ptemp==l27p|ptemp==l28p|ptemp==l29p|ptemp==l30p|ptemp==l31p|ptemp==l32p|ptemp==l33p|ptemp==l34p|ptemp==l35p|ptemp==l36p|ptemp==l37p|ptemp==l38p|ptemp==l39p|ptemp==l40p|ptemp==l41p|ptemp==l42p|ptemp==l43p|ptemp==l44p|ptemp==l45p|ptemp==l46p|ptemp==l47p|ptemp==l48p|ptemp==l49p|ptemp==l50p|ptemp==l51p|ptemp==l52p)
		
		collapse (count) nobs_modal=dp_to_old_modal nobs_regular=dp_to_old_regular (mean) nlags52_refp nlags52_p dp_to_old_modal dp_to_old_regular  (sum) DOLLARS , by(CAT MKT)
		

		append using "./data/dbase_for_price_plan_table3_panelD_moment2_april2020"
		save "./data/dbase_for_price_plan_table3_panelD_moment2_april2020", replace

	}		

}



******************************************************************************************************
*** WEIGHTED MOMENTS (across category & markets)
******************************************************************************************************
	
	
collapse (mean) dp_to_old_modal  [aw=DOLLARS]


******************************************************************************************************
**************** MOMENTS :  Value and description
******************************************************************************************************

**** TABLE III, panel D, moment #2 (Section 4.3) ****
quietly {
noisily: display as text "Prob modal P revisits old modal P (52w window) = " dp_to_old_modal
}


