		********
		********  Table III, panel D, moment #3: Prob revisiting price from before last modal P change
		********
		
clear
clear matrix
clear mata
set more off
set matsize 600
set type double

** <<IMPORTANT>> Note: Use directory of this code as working directory

save "./data/dbase_for_price_plan_table3_panelD_moment3_april2020", emptyok replace


foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		***
		*** Load data
		***

		local infilename ="data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		display "`MKT'"
		display "`CAT'"
		xtset group_id WEEK


		
		*** Define relevant price variable
		gen p = REGPRICE
		drop if p==.

		
		*** Keep only observations for which the price is to the cent
		gen p_dec_100_cent_round = round((p-floor(p))*100-round((p-floor(p))*100),0.001)
		drop if p_dec_100_cent_round~=0
		drop p_*

		
		*** Unique number of prices within window
		gen w1=ceil((WEEK-1000+1)/13)
		gen w2=ceil((WEEK-1001+1)/13)
		gen w3=ceil((WEEK-1002+1)/13)
		gen w4=ceil((WEEK-1003+1)/13)
		gen w5=ceil((WEEK-1004+1)/13)
		gen w6=ceil((WEEK-1005+1)/13)
		gen w7=ceil((WEEK-1006+1)/13)
		gen w8=ceil((WEEK-1007+1)/13)
		gen w9=ceil((WEEK-1008+1)/13)
		gen w10=ceil((WEEK-1009+1)/13)
		gen w11=ceil((WEEK-1010+1)/13)
		gen w12=ceil((WEEK-1011+1)/13)
		gen w13=ceil((WEEK-1012+1)/13)
		
		
		*** Modal price and unique prices in each window		
		forvalues x=1/13{
			bysort group_id w`x': egen nbobs_w`x'=count(p)
			egen temp_w`x'=group(group_id w`x' p)
			bysort group_id w`x':egen temp2_w`x'=min(temp_w`x')
			bysort group_id w`x':egen temp3_w`x'=max(temp_w`x')
			bysort group_id w`x':egen modalp_w`x'=mode(p),maxmode
			replace modalp_w`x'=. if nbobs_w`x'<4
		}
		
		gen modalp=modalp_w1
		forvalues x=2/13{
			gen temp44 = 1007+(`x'-2)
			gen z=(WEEK-temp44)/13-round((WEEK-temp44)/13)
			replace modalp=modalp_w`x' if z==0
			drop z temp44			
		}
		
		drop w* nbobs_w* temp_w* temp2_w* temp3_w* modalp_w*
		
		
		*** Only keep relevant variables
		keep MKT CAT group_id WEEK p REFPRICE modalp DOLLARS

		*** Price changes 
		gen dlp=ln(p)-ln(L.p)
		gen dlp_abs = abs(dlp)
		gen dp_chg = (dlp_abs>0&dlp_abs!=.)		

		*** Replace reference price by modal price
		drop REFPRICE
		gen REFPRICE = modalp
			
		
		***
		*** DEFINE LAGS AND LEADS OF PRICE
		***
		
		xtset group_id WEEK
		
		forvalues x = 1/52{
			gen l`x'refp = L`x'.REFPRICE
			gen l`x'p = L`x'.p
		}
		
		forvalues x = 1/26{
			gen f`x'p = F`x'.p
			gen f`x'dp = F`x'.dp_chg

		}
		
	
		egen nlags52_p = rownonmiss(l1p l2p l3p l4p l5p l6p l7p l8p l9p l10p l11p l12p l13p l14p l15p l16p l17p l18p l19p l20p l21p l22p l23p l24p l25p l26p l27p l28p l29p l30p l31p l32p l33p l34p l35p l36p l37p l38p l39p l40p l41p l42p l43p l44p l45p l46p l47p l48p l49p l50p l51p l52p)
		egen nleads26_p = rownonmiss(f1p f2p f3p f4p f5p f6p f7p f8p f9p f10p f11p f12p f13p f14p f15p f16p f17p f18p f19p f20p f21p f22p f23p f24p f25p f26p)


		********
		********  Table III, panel D, moment #3: Prob revisiting price from before last modal P change
		********

		
		* Drop if not enough observations around the modal dp
		drop if nlags52_p<47
		drop if nleads26_p<23
		
		* Check whether the future price change lands on an old price (last 52 weeks)
		* Starting from the modal price change, find the first price change (within 26-week window
		disp("Look for first price change")
		gen found_dp=0
		gen dp_to_old_price=.
		gen ptemp=.
		gen nleads_dp_26=0
		*drop if newprice52_accept!=.
		forvalues x = 1/26{
			
			* Nb of dp
			replace nleads_dp_26=nleads_dp_26+1 if f`x'dp!=.
			* Keeps track of which price change we are at
			replace found_dp=found_dp+1 if f`x'dp==1
			* First price change following BNP
			replace dp_to_old_price = 0 if dp_to_old_price==.&f`x'dp==1&found_dp==1
			replace ptemp = f`x'p
			* Check if first price change after BNP ends up at a price that was posted in the 52 weeks before that BNP
			replace dp_to_old_price = 1 if f`x'dp==1&found_dp==1&ptemp!=.&(ptemp==l1p|ptemp==l2p|ptemp==l3p|ptemp==l4p|ptemp==l5p|ptemp==l6p|ptemp==l7p|ptemp==l8p|ptemp==l9p|ptemp==l10p|ptemp==l11p|ptemp==l12p|ptemp==l13p|ptemp==l14p|ptemp==l15p|ptemp==l16p|ptemp==l17p|ptemp==l18p|ptemp==l19p|ptemp==l20p|ptemp==l21p|ptemp==l22p|ptemp==l23p|ptemp==l24p|ptemp==l25p|ptemp==l26p)
			
		}
		
			
		collapse (mean) dp_to_old_price  (sum) DOLLARS , by(CAT MKT)

		append using "data/dbase_for_price_plan_table3_panelD_moment3_april2020"
		save "data/dbase_for_price_plan_table3_panelD_moment3_april2020", replace

	}		

}



******************************************************************************************************
*** WEIGHTED MOMENTS (across category & markets)
******************************************************************************************************
	
	
collapse (mean) dp_to_old_price  [aw=DOLLARS]


******************************************************************************************************
**************** MOMENTS :  Value and description
******************************************************************************************************

**** TABLE III, panel D, moment #3 (Section 4.3) ****
quietly {
noisily: display as text "Prob revisiting price from before last modal P change = " dp_to_old_price
}


