********
********  Table III, panel D, moment #4: Prob revisiting price from before brand new price
********
		
clear
clear matrix
clear mata
set more off
set matsize 600
set type double


** <<IMPORTANT>> Note: Use directory of this code as working directory

save "./data/dbase_for_price_plan_table3_panelD_moment4_april2020", emptyok replace


foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {
	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		***
		*** Load data
		***
		local infilename = "I:/data/IRI/dispersion/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		display "`MKT'"
		display "`CAT'"
		xtset group_id WEEK

				
		*** Define relevant price variable
		drop p
		gen p = REGPRICE
		drop if p==.

		
		*** Keep only observations for which the price is to the cent
		gen p_dec_100_cent_round = round((p-floor(p))*100-round((p-floor(p))*100),0.001)
		drop if p_dec_100_cent_round~=0
		drop p_*

		*** Only keep relevant variables
		keep MKT CAT group_id WEEK p DOLLARS
				
		*** Price changes 
		gen dlp=ln(p)-ln(L.p)
		gen dlp_abs = abs(dlp)
		gen dlp_abs_nonzero = dlp_abs
		replace dlp_abs_nonzero = . if dlp_abs==0
		
		*** Price change indicators
		gen dp_chg = (dlp_abs>0&dlp_abs!=.)

		
		***
		*** DEFINE LAGS AND LEADS OF PRICE
		***
		
		xtset group_id WEEK
		
		forvalues x = 1/52{
			gen l`x'p = L`x'.p
		}
		
		forvalues x = 1/26{
			gen f`x'p = F`x'.p
			gen f`x'dp = F`x'.dp_chg
		}
		

		
		************
		************ PRICE PLAN MOMENTS
		************
		
		disp("Compute lags")
		gen P = p
		egen nlags26 = rownonmiss(l1p l2p l3p l4p l5p l6p l7p l8p l9p l10p l11p l12p l13p l14p l15p l16p l17p l18p l19p l20p l21p l22p l23p l24p l25p l26p)
		egen nlags52 = rownonmiss(l1p l2p l3p l4p l5p l6p l7p l8p l9p l10p l11p l12p l13p l14p l15p l16p l17p l18p l19p l20p l21p l22p l23p l24p l25p l26p l27p l28p l29p l30p l31p l32p l33p l34p l35p l36p l37p l38p l39p l40p l41p l42p l43p l44p l45p l46p l47p l48p l49p l50p l51p l52p)
	
		disp("Computing oldprice and newprice")
		* Old price
		gen oldprice52 = 0 if P!=.
		gen ptemp=P
		replace oldprice52 = 1 if P!=.&(ptemp==l1p|ptemp==l2p|ptemp==l3p|ptemp==l4p|ptemp==l5p|ptemp==l6p|ptemp==l7p|ptemp==l8p|ptemp==l9p|ptemp==l10p|ptemp==l11p|ptemp==l12p|ptemp==l13p|ptemp==l14p|ptemp==l15p|ptemp==l16p|ptemp==l17p|ptemp==l18p|ptemp==l19p|ptemp==l20p|ptemp==l21p|ptemp==l22p|ptemp==l23p|ptemp==l24p|ptemp==l25p|ptemp==l26p|ptemp==l27p|ptemp==l28p|ptemp==l29p|ptemp==l30p|ptemp==l31p|ptemp==l32p|ptemp==l33p|ptemp==l34p|ptemp==l35p|ptemp==l36p|ptemp==l37p|ptemp==l38p|ptemp==l39p|ptemp==l40p|ptemp==l41p|ptemp==l42p|ptemp==l43p|ptemp==l44p|ptemp==l45p|ptemp==l46p|ptemp==l47p|ptemp==l48p|ptemp==l49p|ptemp==l50p|ptemp==l51p|ptemp==l52p)
		drop ptemp
		* Identify a brand new price
		gen newprice52 = 0 if dp_chg==1&P!=.&L.P!=.&nlags52>=47
		replace newprice52 = 1 if dp_chg==1&P!=.&L.P!=.&nlags52>=50&oldprice52==0
		* Only consider brand new prices that have not been recently preceded by another brand new price in the last 26 weeks
		gen newprice52_accept = newprice52
		replace newprice52_accept = . if nlags26<23	
		replace newprice52_accept = 0 if newprice52_accept!=.&(L.newprice52==1|L2.newprice52==1|L3.newprice52==1|L4.newprice52==1|L5.newprice52==1|L6.newprice52==1|L7.newprice52==1|L8.newprice52==1|L9.newprice52==1|L10.newprice52==1|L11.newprice52==1|L12.newprice52==1|L13.newprice52==1|L14.newprice52==1|L15.newprice52==1|L16.newprice52==1|L17.newprice52==1|L18.newprice52==1|L19.newprice52==1|L20.newprice52==1|L21.newprice52==1|L22.newprice52==1|L23.newprice52==1|L24.newprice52==1|L25.newprice52==1|L26.newprice52==1)

		* Get rid of all non-accept new prices, or those that have too little lags
		drop if newprice52_accept!=1&nlags52<47
		
		* Starting from the BNP, find the first price change (within 26-week window
		disp("Look for first price change")
		gen found_dp=0
		gen dp_to_old_price=.
		gen ptemp=.
		gen nleads_dp_26=0
		forvalues x = 1/26{
			
		* Nb of dp
		replace nleads_dp_26=nleads_dp_26+1 if f`x'dp!=.
		* Keeps track of which price change we are at
		replace found_dp=found_dp+1 if f`x'dp==1
		* First price change following BNP
		replace dp_to_old_price = 0 if dp_to_old_price==.&f`x'dp==1&found_dp==1
		replace ptemp = f`x'p
		* Check if first price change after BNP ends up at a price that was posted in the 52 weeks before that BNP
		replace dp_to_old_price = 1 if f`x'dp==1&found_dp==1&ptemp!=.&(ptemp==l1p|ptemp==l2p|ptemp==l3p|ptemp==l4p|ptemp==l5p|ptemp==l6p|ptemp==l7p|ptemp==l8p|ptemp==l9p|ptemp==l10p|ptemp==l11p|ptemp==l12p|ptemp==l13p|ptemp==l14p|ptemp==l15p|ptemp==l16p|ptemp==l17p|ptemp==l18p|ptemp==l19p|ptemp==l20p|ptemp==l21p|ptemp==l22p|ptemp==l23p|ptemp==l24p|ptemp==l25p|ptemp==l26p|ptemp==l27p|ptemp==l28p|ptemp==l29p|ptemp==l30p|ptemp==l31p|ptemp==l32p|ptemp==l33p|ptemp==l34p|ptemp==l35p|ptemp==l36p|ptemp==l37p|ptemp==l38p|ptemp==l39p|ptemp==l40p|ptemp==l41p|ptemp==l42p|ptemp==l43p|ptemp==l44p|ptemp==l45p|ptemp==l46p|ptemp==l47p|ptemp==l48p|ptemp==l49p|ptemp==l50p|ptemp==l51p|ptemp==l52p)
			
		}

		replace dp_to_old_price = . if nleads_dp_26<23
		
		collapse (count) nobs=dp_to_old_price (mean) dp_chg nleads_dp_26 found_dp dp_to_old_price newprice52 newprice52_accept  (sum) DOLLARS , by(CAT MKT)
		
		append using "data/dbase_for_price_plan_table3_panelD_moment4_april2020"
		save "data/dbase_for_price_plan_table3_panelD_moment4_april2020", replace

	}		

}



******************************************************************************************************
*** WEIGHTED MOMENTS (across category & markets)
******************************************************************************************************
	
	
collapse (mean) dp_to_old_price  [aw=DOLLARS]


******************************************************************************************************
**************** MOMENTS :  Value and description
******************************************************************************************************

**** TABLE III, panel D, moment #4 (Section 4.3) ****
quietly {
noisily: display as text "Prob revisiting price from before brand new price = " dp_to_old_price
}


