%%%%%%%%
%%% Code to identify pricing regimes based on Luminata Stevens' methodology
%%%
%%% IMPORTANT: the Stata code "create_dbase_for_breaks_april2020.do" should
%%% be run first.

%%% Current directory should be set as path

clc
clear all

cat_vec = ["beer","coldcer","fzdinent","fzpizza","saltsnck","yogurt"];
mkt_vec = ["ATL","BOS","CHI","DAL","HOU","LA","NYC","PHI","SF"];

nb_mkt_cat = size(cat_vec,2)*size(mkt_vec,2);

breaks_vec=[];
duration_vec=[];
catnum_vec=[];
mktnum_vec=[];
weight_vec=[];

for j=1:size(cat_vec,2)
    
    for k=1:size(mkt_vec,2)
        
        disp(cat_vec(j))
        disp(mkt_vec(k))
        
        % Load data
        filename=strcat('../data/db_pricing_regimes_',cat_vec(j),'_',mkt_vec(k),'.csv');
        data=readtable(filename);
        P = data{:,{'P'}};
        group_id = data{:,{'group_id'}};
        weight = data{:,{'weight'}};
        
        % Number of unique group_id
        nb_groupid = size(unique(group_id),1);

        % Indicator of a change of group_id in the price series
        d_group_id = group_id(2:end)-group_id(1:end-1);
        new_group_id = [1;d_group_id~=0];

        % Index of first observation for each group_id
        index_vec = find(new_group_id);


        %%%%%%%%%%
        % Apply Stevens' code for each group_id price series
        %%%%%%%%%%

        duration_vec_catmkt=[];
        for i=1:nb_groupid-1

            % Identify regime changes (Stevens' original code)
            [temp,stats] = break_test_basic(P(index_vec(i):index_vec(i+1),1),5);
            breaks_vec = [breaks_vec;temp];

            % Find index value of each regime break
            temp2=find(temp);
            
            % Duration of each regime (we drop first and last spells)
            duration = temp2(2:end)-temp2(1:end-1);
            duration_vec_catmkt = [duration_vec_catmkt;duration];

        end

        %%% Associate a cat and mkt number
        catnum_vec = [catnum_vec;j*ones(size(duration_vec_catmkt,1),1)];
        mktnum_vec = [mktnum_vec;k*ones(size(duration_vec_catmkt,1),1)];
        weight_vec = [weight_vec;weight(1)*ones(size(duration_vec_catmkt,1),1)]; 
        duration_vec=[duration_vec;duration_vec_catmkt];

    end

   

    
end

%%% Save dbase
save pricing_regime_full_dbase

%%% Table 2, line 6: "Mean duration of pricing regimes"
disp("Mean duration of pricing regimes")
disp(mean(duration_vec))