********************************************************************************************************************************************
** This code does two main things:
**	Part 1: For each category/market, generates the discreetness moment "uni" in Table III, Panel B (see 4.2.1)
**  Part 2: Creates aggregate moment (weighted across cat/mkt)
********************************************************************************************************************************************

clear
clear matrix
clear mata
set more off
set matsize 600


** <<IMPORTANT>> Note: Use directory of this code as working directory

save "/data/dbase_for_uni_moment_rep_april2020", emptyok replace

foreach MKT in ATL BOS CHI DAL HOU LA NYC PHI SF {

	foreach CAT in beer coldcer fzdinent fzpizza saltsnck yogurt{

		***
		*** Load data
		***

		local infilename ="data/allprices_allyears_wsales_"+"`CAT'"+"_"+"`MKT'"
		use "`infilename'"
		
		gen CAT = "`CAT'"
		gen MKT = "`MKT'"
		display "`MKT'"
		display "`CAT'"
		
		xtset group_id WEEK

		
		*** Define relevant price variable (regular price)
		gen p = REGPRICE
		drop if p==.

		
		*** Keep only observations for which the price is to the cent (to limit spurious price changes)
		gen p_dec_100_cent_round = round((p-floor(p))*100-round((p-floor(p))*100),0.001)
		drop if p_dec_100_cent_round~=0
		drop p_*
	
				
		*** Price changes 
		gen dlp=ln(p)-ln(L.p)
		gen dp_dum = 1 if dlp!=0&dlp!=.
		replace dp_dum = 0 if dlp==0

		
		*** Only keep useful variables
		keep group_id WEEK DOLLARS p dp_dum CAT MKT

		
		*************************************************
		*** # of price changes and unique number of prices within 26-week window
		*************************************************
		disp("26-week window")
		
		gen w1=ceil((WEEK-1000+1)/26)
		gen w2=ceil((WEEK-1001+1)/26)
		gen w3=ceil((WEEK-1002+1)/26)
		gen w4=ceil((WEEK-1003+1)/26)
		gen w5=ceil((WEEK-1004+1)/26)
		gen w6=ceil((WEEK-1005+1)/26)
		gen w7=ceil((WEEK-1006+1)/26)
		gen w8=ceil((WEEK-1007+1)/26)
		gen w9=ceil((WEEK-1008+1)/26)
		gen w10=ceil((WEEK-1009+1)/26)
		gen w11=ceil((WEEK-1010+1)/26)
		gen w12=ceil((WEEK-1011+1)/26)
		gen w13=ceil((WEEK-1012+1)/26)
		gen w14=ceil((WEEK-1013+1)/26)
		gen w15=ceil((WEEK-1014+1)/26)
		gen w16=ceil((WEEK-1015+1)/26)
		gen w17=ceil((WEEK-1016+1)/26)
		gen w18=ceil((WEEK-1017+1)/26)
		gen w19=ceil((WEEK-1018+1)/26)
		gen w20=ceil((WEEK-1019+1)/26)
		gen w21=ceil((WEEK-1020+1)/26)
		gen w22=ceil((WEEK-1021+1)/26)
		gen w23=ceil((WEEK-1022+1)/26)
		gen w24=ceil((WEEK-1023+1)/26)
		gen w25=ceil((WEEK-1024+1)/26)
		gen w26=ceil((WEEK-1025+1)/26)
		
		*** Nb of price changes and unique prices in each window		
		disp("Loop 1")
		forvalues x=1/26{
			disp(`x')
			sort group_id w`x'
			by group_id w`x': egen nbobs_w`x'=count(p)
			egen temp_w`x'=group(group_id w`x' p)
			by group_id w`x':egen temp2_w`x'=min(temp_w`x')
			by group_id w`x':egen temp3_w`x'=max(temp_w`x')
			gen unique_w`x' = temp3_w`x'-temp2_w`x'+1
			replace unique_w`x'=. if nbobs_w`x'<26

			bysort group_id w`x': egen nbdp_w`x'=sum(dp_dum)
			bysort group_id w`x': egen nbobs_dp_w`x'=count(dp_dum)
			replace nbdp_w`x'=. if nbobs_dp_w`x'<26
		}
		
		disp("Loop 2")		
		gen unique_26=unique_w1
		gen nbdp_26=nbdp_w1
		forvalues x=2/26{
			disp(`x')
			gen temp44 = 1013+(`x'-2)
			gen z=(WEEK-temp44)/26-round((WEEK-temp44)/26)
			replace unique_26=unique_w`x' if z==0
			replace nbdp_26=nbdp_w`x' if z==0
			drop z temp44			
		}
	
		
		*** Ratio
		gen ratio_unique_26 = unique_26/(nbdp_26+1)
		replace ratio_unique_26=. if nbdp_26==0

		
		***********
		* Collapse across products (within a specific category/market)
		***********
		collapse (mean) ratio_unique_26 (sum) DOLLARS, by(CAT MKT)
		
		append using "data/dbase_for_uni_moment_rep_april2020"
		save "data/dbase_for_uni_moment_rep_april2020", replace

	}		

}




******************************************************************************************************
*** WEIGHTED MOMENT (across category & markets)
******************************************************************************************************

collapse (mean) ratio_unique_26 [aw=DOLLARS]


******************************************************************************************************
**************** MOMENT :  Value and description
******************************************************************************************************


**** TABLE III, panel B (Section 4.2.1) ****
quietly {
noisily: display as text "uni (26-week window) = " ratio_unique_26
}



