
%  This fucntion takes a vector of prices, and evaluates the max-min
%  log-demand, using GP priors and enforcing the slope restrictions of the
%  prior set \Upsilon. The slope (anywhere) of any given prior cannot be bigger than b_max. 

function [GPupdate, PostVar] = GPupdate_slr(p,pObs,yObs,nObs,gamma_h,b_h,gamma_l,b_l,sigma_z,psi, sigma_x,pGrid,b_max)%ldmm0(x,P,Q,q_h,s_h,q_l,s_l,alpha,sigma,pGrid)


p_h = max(pGrid);
p_l = min(pGrid);


[n1,k1] = size(pObs);
[n2,k2] = size(yObs);
[n3,k3] = size(nObs);

if (n1 - n2)~=(n3-n2) || (k1 - k2)~=(k2-k3)
    error('GPupdate error-> P0, Y0 and N0 inputs must have the same size!')
elseif k1~=1 || k2~=1 || k3~=1
    error('GPupdate error-> P0, Y0 and N0 inputs must be nX1 column vectors!')
else
    n = n1;
    clear n1 n2 k*
end

%to check if q_h>q_l and that the slopes are both negative:
if gamma_h<=gamma_l
    error('GPupdate error-> gamma_h must be bigger than gamma_l!')
end
if b_h>=0 || b_l >=0
    error('GPupdate error-> slopes must be negative!')
end


if abs(b_h)>abs(b_l)
    if b_h*(gamma_l-gamma_h)/(b_h-b_l)+gamma_h>=0
        error('GPupdate error-> outer lines intersect in the first orthant!')
    end
end
%%
data  = sortrows([pObs yObs nObs]); %sorted data for price and quantity

unique_p  = unique(data(:,1));
for i=1:length(unique_p)
    indt = find(data(:,1)==unique_p(i,1));
    if length(indt)>1;
        datat = data(indt,:);
        nt    = sum(datat(:,3));
        avt   = sum(datat(:,2).*datat(:,3))/nt;
        data(indt,:) = [];
        data  = [data; datat(1) avt nt];
        data  = sortrows(data);
        if i == size(data,1)
            break
        end
    end
end

pU    = data(:,1); %sorted and unique prices
yM    = data(:,2); %sorted mean for quantities
ySE    = sigma_z./sqrt(data(:,3)); %sorted standard-deviation for quantities

n = length(pU);

%this part checks if any data point is outside the current price grid
if pU(1)<p_l || pU(end)>p_h
    warning('GPupdate-> some data points are outside the price grid!')
    warning('GPupdate -> these data points are discarded!')
end

if prod(pU<p_l | pU>p_h)==1
    error('GPupdate error-> all data points are outside the price grid')
end

%this part gets rid of the data that are outside the grid limits
ind = pU>=p_l & pU<=p_h;
pU  = pU(ind);
yM  = yM(ind);
ySE  = ySE(ind);

%% Compute alpha -- the vector of weights for the signals where
%%%  E(x(p) | y ) = m(p) + alpha'(y - m)
%%% Start with expressing everything as multivariate normal

Sigma12 = NaN(length(p),n);
Kp0p1 = NaN(n,n);

alpha = NaN(length(p), length(pU));

for i = 1:n
    
    %%% Squared exponential variance function -- alpha's might be negative!
    Sigma12(:,i) = (sigma_x^2*exp(-psi^2*(p - pU(i)).^2))';
    Kp0p1(:,i) = sigma_x^2*exp(-psi^2*(pU - pU(i)).^2);
   
end

Sigma22 = Kp0p1 + diag(ones(n,1).*(ySE.^2));

alpha = Sigma12/Sigma22;

PostVar = diag(sigma_x^2 - (Sigma12/Sigma22)*(Sigma12'))';

%%% Compute worst-case demand

GPupdate = NaN(1,length(p));

if max(p)> pU(end)
    slr_max = bsxfun(@minus,gamma_l + (b_h+abs(b_max))*p(p> pU(end)), abs(b_max)*pU);  %%% max worst-case prior m*(p), given slope restrictions
    GPupdate(p>pU(end)) = gamma_l + b_h*p(p>pU(end))' + diag(alpha(p> pU(end),:)*(bsxfun(@minus,yM, bsxfun(@min,slr_max,gamma_h + b_h*pU))));
end

if max(p) > pU(1) && min(p) <= pU(end)
    for i=1:n-1
        ind_below = 1:n-i;
        ind_above = n-i+1:n;
        slr_max = bsxfun(@minus,gamma_l + (b_h+abs(b_max))*p(p> pU(end-i) & p<= pU(end-i+1)), abs(b_max)*pU(ind_below));  %%% max worst-case prior m*(p), given slope restrictions
        %yhat_low = alpha(p> pU(end-i) & p<= pU(end-i+1),ind_below)*(yM(ind_below) - (gamma_h + b_h*pU(ind_below)));
        yhat_low = diag(alpha(p> pU(end-i) & p<= pU(end-i+1),ind_below)*(bsxfun(@minus,yM(ind_below), bsxfun(@min,slr_max,gamma_h + b_h*pU(ind_below)))));
        %yhat_high = alpha(p> pU(end-i) & p<= pU(end-i+1),ind_above)*(yM(ind_above) - min((gamma_l + b_h*p(p> pU(end-i) & p<= pU(end-i+1))),gamma_h + b_h*pU(ind_above)));
        yhat_high = diag(alpha(p> pU(end-i) & p<= pU(end-i+1),ind_above)*(bsxfun(@minus,yM(ind_above), bsxfun(@min,gamma_l +  b_h*p(p> pU(end-i) & p<= pU(end-i+1)),gamma_h + b_h*pU(ind_above)))));
        GPupdate(p> pU(end-i) & p<= pU(end-i+1)) = (gamma_l + b_h*p(p> pU(end-i) & p<= pU(end-i+1)))' + yhat_low + yhat_high;
    end
end

if min(p) <=pU(1)
    GPupdate(p<= pU(1)) = (gamma_l + b_h*p(p<=pU(1)))' + diag(alpha(p<=pU(1),:)*(bsxfun(@minus,yM, bsxfun(@min,gamma_l +  b_h*p(p<=pU(1)),gamma_h + b_h*pU))));
end


end
