
function [dmax,n] = getdiff(x1,x2) 

% -------------------------------------------------------------------------    
%  getdiff.m
%
%  Project: “Coarse Pricing Policies“
%           Luminita Stevens, University of Maryland
%
%  Description: Compute Kolmogorov-Smirnov distance between two samples 
%
%  Input: 
%   x1   :  vector, sample 1 
%   x2   :  vector, sample 2
%
%  Output: 
%   dmax : K-S 2-sample test statistic 
%   n    : K-S 2-sample normalization factor   
% -------------------------------------------------------------------------


% Compute F1(x) and F2(x), the sample CDFs.
binEdges = [-inf ; sort([x1(:,1);x2(:,1)]) ; inf];
binEdges = binEdges(~isnan(binEdges));

binCounts1 = histc (x1 , binEdges, 1);
binCounts2 = histc (x2 , binEdges, 1);

sumCounts1 = cumsum(binCounts1,1)./(ones(size(binCounts1,1),1)*sum(binCounts1,1));
sumCounts2 = cumsum(binCounts2,1)./(ones(size(binCounts2,1),1)*sum(binCounts2,1));

sampleCDF1 = sumCounts1(1:end-1,:);
sampleCDF2 = sumCounts2(1:end-1,:);

% Compute the test statistic.
deltaCDF  = abs(sampleCDF1 - sampleCDF2);
dmax      = max(deltaCDF)'; 


% Compute the normalization for the test statistic.
n1  =  sum(~isnan(x1))';
n2  =  sum(~isnan(x2))';
n   =  n1 .* n2 ./((n1 + n2).^2);


end
