
addpath('ME discretization/')

%%%%%%%%%%%%%%%%%%%%%%%%% Figure 2 .  %%%%%%%%%%%%%%%%%%%%%%%%%

%%% Set parameters for the worst-case demand illustration (default: same as
%%% quantitative calibratinon)

%%%% Macro parameters
theta = 6;                %%%% price elasticity of demand
mu = theta/(theta-1);     %markup for RE firm with full information

sigma_z = 0.6128359;
sigma_eps_ambig=sigma_z;  %std. deviation that sets the width of set of multiple priors

rho_c = 0.998;
sigma_c = 0.008;
cbar = 1/mu;
n_c = 3;   %%% Defines how many standard deviations around mean are included in the grid for c

%%% Learning and Ambiguity Parameters
alpha = 1.96;
b_h = -theta; 
b_l = b_h;

sigma_x     = 0.6915;  
psi         = 4.6093;  
b_max       = -12;
n           = 1.0022;   

gamma_h = n*sigma_eps_ambig;
gamma_l = -n*sigma_eps_ambig;
midQ = (gamma_h+gamma_l)/2;   %%%%mid-intercept

%%% Set grid size
c_nodes = 1001;  
p_nodes = 5001;  

tol = 0.01;


%%%% All exogenous variables are in logs
c_grid = linspace( - 5*sqrt( sigma_c/( 1- rho_c^2)), 5*sqrt( sigma_c/( 1- rho_c^2)), c_nodes); 
c_grid = c_grid + log(cbar);
c_grid = linspace( max(-0.6, c_grid(1)), min(0.25, c_grid(end)), c_nodes);

%c_grid = log(cbar) + linspace( -0.01, 0.01, c_nodes); 

p_grid = linspace(min(c_grid + log(theta/(theta-1))*0),max(c_grid)+log(theta/(theta-1))*2,p_nodes);    %%%% grid on log-price
%p_grid = linspace(-0.00051,0.00051); 
p = p_grid;

%%% Initial Conditions

% Optimal chosen prices: -0.1032, 0.07]; 
p0 = [0.075];  %0 and 0.175 for policy functions, 0 for exp demand 1 price, -0.05 and 0.05 for exp demand 2 prices 

for i = 1:length(p0)    
    [~,p0_ind] = min(abs(p - p0(i))); %define P0
    p0(i) = p(p0_ind);   
end

n0 = [1]; 
v =  [0];

y0 = midQ + b_h*p0 + v*sigma_z./sqrt(n0);  % average signal at P0


qDemand_slr    = GPupdate_slr(p ,[p0],[y0],[n0] ,gamma_h,b_h,gamma_l,b_l,sigma_z,psi,sigma_x,p,b_max);

figure
plot(p, qDemand_slr, 'LineWidth',3)
xlim([-0.25, 0.25])
vline(p0(1),'k:','$p_0$',14,1,1)
%vline(p0(2),'k:','$p_1$',14,1,1)
h = legend('$\widehat x^*(p | \bar y_0)$');
set(h,'FontSize',13,'interpreter','latex')
xlabel('Log Price','FontSize',13)
ylabel('Log quantity','FontSize',13)
set(gca,'XTick',[], 'YTick', [])
title('Worst-Casse Demand, one previously observed price')

% Optimal chosen prices: -0.1032, 0.07]; 
p0 = [-0.05; 0.05];  %0 and 0.175 for policy functions, 0 for exp demand 1 price, -0.05 and 0.05 for exp demand 2 prices 

for i = 1:length(p0)    
    [~,p0_ind] = min(abs(p - p0(i))); %define P0
    p0(i) = p(p0_ind);   
end

n0 = [1; 1]; 
v =  [0; 0];

y0 = midQ + b_h*p0 + v*sigma_z./sqrt(n0);  % average signal at P0

qDemand_slr    = GPupdate_slr(p ,[p0],[y0],[n0] ,gamma_h,b_h,gamma_l,b_l,sigma_z,psi,sigma_x,p,b_max);


figure
plot(p, qDemand_slr, 'LineWidth',3)
xlim([-0.25, 0.25])
vline(p0(1),'k:','$p_0$',14,1,1)
vline(p0(2),'k:','$p_1$',14,1,1)
h = legend('$\widehat x^*(p | \bar y_0)$');
set(h,'FontSize',13,'interpreter','latex')
xlabel('Log Price','FontSize',13)
ylabel('Log quantity','FontSize',13)
set(gca,'XTick',[], 'YTick', [])
title('Worst-Casse Demand, two previously observed prices')

%%
%%%%%%%%%%%%%%%%%%%%%%%%%% Quanitative Model Results %%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%% Moments for Tables 2 and 3 %%%%%%%%%%%%%%%%%%%%%%%%%%

rng('default');

%%%%%%%%%%%%%%%%%%%%%%%%%      Calibration of Parameters      %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Macro parameters
beta=0.97^(1/52);
chi = 1; %%% labor preference parameter

b = 6; %%%% price elasticity of demand
mu = b/(b-1); %markup for RE firm with full information


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Exogenous shocks
%%%%% S_t
mu_s = 0.00046;        %%% Annual inflation of 2.4%

rho_s = 1;
sigma_eps_s = 0.0015;  %%% Annual std dev. of 1.1%

%%%%% a_t
rho_a = 0.91^(1/13);   %%% Vavra (transformed to weekly)
sigma_eps_a = 0.006/(sqrt((1-rho_a^26)/(1-rho_a^2))); %%% Vavra's numbers transformed to weekly

%%%%% Z_it
sigma_z = 0.6128359;   %%% Calibrated based on prediction error from weekly regressions

%%%% Probability of product reset / end
lam_phi= 0.0075;


%%%%% Estimated parameters
rho_w       = 0.9985;
sigma_eps_w = 0.0084;
sigma_x     = 0.6915;
psi         = 4.6093;
lambda_T    = 0.0180;
b_max       = -12;
n           = 1.0022;

%%%%% Global simulation parameters
T_sims_glb    =  5000;
num_firms_glb =  1000;
burn_in_glb   =  1000;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  Learning and Ambiguity Parameters

gamma_h = n*sigma_z;  %%% how many std. deviation of the noise shock the firm considers in order to build the tunnel
gamma_l = -n*sigma_z;


midQ = (gamma_h+gamma_l)/2;   %%%%mid-intercept

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Simulation parameters

p_nodes = 201; % Price grid ( choice variable)
pref_nodes = 200;
yref_nodes = 101; %This is only needed to initialize starting information, which we set to almost zero (n0 = 0.001). Does not directly matter,
%but is just convenient to keep because of the structure of the code.
n_y = 3;    % Std deviation coverage, only needed with reference to above line

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Length of simulation
T_sims    =  T_sims_glb;
num_firms =  num_firms_glb;
burn_in   =  burn_in_glb;


%%%%%%%%% Parameterizing grids for integrals over continuation value
qref_nodes = 5;  %%% number of grid points on demand shock support
w_nodes = 21; %%%% number of grid points on idiosyncratic productivity support 

tol = 0.01;

%%% Computing a Finite State Markov Process Approximation of AR(1)
%%% using FarmerToda(2015)
[pdf_w_mat,w_grid] = discreteVAR( 0 ,rho_w,sigma_eps_w^2,w_nodes, 2 , 'quantile');

[z_grid,w_z] = hermquad(qref_nodes);
z_grid = sqrt(2)*sigma_z*z_grid;

pdf_w =  pdf_w_mat^1000;
pdf_w = pdf_w(1,:)';
cdf_w = NaN(size(pdf_w));

for i = 1:w_nodes
    
    cdf_w(i) = sum(pdf_w(1:i));
    
end

cdf_w(end)  = 1;

w_ints = norminv(cdf_w(1:end-1),0, sqrt(sigma_eps_w^2/(1-rho_w^2)));

pdf_z = w_z./sum(w_z);
pdf_zw = pdf_z*pdf_w';

beta = beta*(1-lam_phi);
beta_inv = (eye(w_nodes) - beta*pdf_w_mat)\eye(w_nodes);


%%%%%
%%%%% Simulating a panel of firms
%%%%%

%%% Initial Price History
p0 = -0*0.0225;
%p0 = log(mu*chi);
pagg0 = 0;%log(mu*chi) + mu_s;
y0_perc = [50];
n0 = 0.0001;

y0 = NaN(size(p0));
for i = 1:length(p0)
    y_grid = lgwt(yref_nodes, midQ+b_l*(p0(i) - pagg0(i))-n_y*sigma_z, midQ+b_h*(p0(i) - pagg0(i))+n_y*sigma_z);  %%% The signals are noisy because of z_it.
    y0(i) = y_grid(round(prctile(1:yref_nodes,y0_perc(i)))');
end

sigma_w = sqrt(sigma_eps_w^2/(1-rho_w^2));

%%% Initial Exogenous states
s0 = mu_s;
a0 = 0;
w0 = 0;

params = [midQ,-b, sigma_eps_s, sigma_eps_a,sigma_eps_w, sigma_z, mu_s, rho_s, rho_a, rho_w, b, chi, b_l, gamma_h, gamma_l,f, mu, p_nodes,pagg0,lambda_T,psi, sigma_x, b_max, lam_phi, beta, pref_nodes];

init_conds_ex =[s0,a0,w0];

eps_a_temp = sigma_eps_a*normrnd(0,1,T_sims,1);
eps_s_temp = sigma_eps_s*normrnd(0,1,T_sims,1);
eps_w_mat_temp = sigma_eps_w*normrnd(0,1,T_sims,num_firms);
eps_z_mat_temp  = sigma_z*normrnd(0,1,T_sims,num_firms);
lambdaT_rand_mat   = rand(T_sims, num_firms);
lambdaPhi_rand_mat = rand(T_sims, num_firms);

eps_a = NaN(T_sims,1);
eps_s = NaN(T_sims,1);
eps_w = NaN(T_sims,1);
eps_z = NaN(T_sims,1);

eps_a(1:T_sims) = eps_a_temp;
eps_s(1:T_sims) = eps_s_temp;

pmax_sims = NaN(T_sims, num_firms);
pmax_menuc_sims = NaN(T_sims, num_firms);
rmax_sims = NaN(T_sims, num_firms);

y_hist_sims = NaN(T_sims, num_firms);
n_hist_sims = NaN(T_sims, num_firms);
pjs_sims    = NaN(T_sims, num_firms);
s_sims      = NaN(T_sims, num_firms);
z_sims      = NaN(T_sims, num_firms);
a_sims      = NaN(T_sims, num_firms);
w_sims      = NaN(T_sims, num_firms);



%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Perform simulations
%%%
tic
parfor ii = 1:num_firms
    
    %eps_w = [eps_w_mat_temp(:,ii); NaN(100000-T_sims,1)];
    %eps_z = [eps_z_mat_temp(:,ii); NaN(100000-T_sims,1)];
    
    eps_w               = eps_w_mat_temp(:,ii);
    eps_z               = eps_z_mat_temp(:,ii);
    lambdaT_rand        = lambdaT_rand_mat(:,ii);
    lambdaPhi_rand  = lambdaPhi_rand_mat(:,ii);
    
    [rmax_sims_temp,pmax_menuc_temp,pflex_sims_temp,bound_hits,a_sims_temp,z_sims_temp,s_sims_temp,w_sims_temp,pjs_sims_temp,y_hist_temp, n_hist_temp] = sim_panel(init_conds_ex,p0,n0,y0,T_sims,eps_a,eps_s,eps_w,eps_z,lambdaT_rand,lambdaPhi_rand,z_grid, w_grid, beta_inv, w_ints, pdf_z, params);

    pmax_sims(:,ii) = rmax_sims_temp + pjs_sims_temp;
    rmax_sims(:,ii) = rmax_sims_temp;
    y_hist_sims(:,ii) = y_hist_temp;
    pjs_sims(:,ii) = pjs_sims_temp;
    n_hist_sims(:,ii) = n_hist_temp;
    
    pmax_menuc_sims(:,ii) = pmax_menuc_temp;
    
    s_sims(:,ii) = s_sims_temp;
    z_sims(:,ii) = z_sims_temp;
    a_sims(:,ii) = a_sims_temp;
    w_sims(:,ii) = w_sims_temp;
    
    if bound_hits > 0
        warning(strcat( 'Boundary hit at ', num2str(ii)))
    end
    
end
toc

%%%%%%%%%%%%%%%%%% Aggregate price and output indeces of the measure-zero ambiguity averse firms

p_agg_sims = log((b/(b-1))*chi*exp(s_sims-a_sims + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
c_agg_sims = log(((b-1)/b)*(1/chi)*exp(a_sims - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));

p_agg_sims = p_agg_sims(:,1);
c_agg_sims = c_agg_sims(:,1);

save replication.mat

compute_moments

save replication.mat

erg_policy

save replication.mat 

return
%%  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  Monetary Policy Impulse response


%%%%% Here we simulate T = 10,000, N = 5000 panel to smooth out Monte Carlo
%%%%% error in the Jorda estimate of the IRF. We simulate it twice, once
%%%%% with nominal shocks and once without, then take the difference to
%%%%% control for small sample errors. 

rng('default')

%%%%% Change size of simulation
T_sims_mpirf    =  10000;
num_firms_mpirf =  5000;
burn_in_mpirf   =  1000;

%%%% number of periods for the IRF
irf_periods = 52;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%       1) Simulate panel of ambiguity averse firms

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Length of simulation
T_sims    =  T_sims_mpirf;
num_firms =  num_firms_mpirf;
burn_in   =  burn_in_mpirf;

%%% Initial Exogenous states
s0 = mu_s;
a0 = 0;
w0 = 0;

params = [midQ,-b, sigma_eps_s, sigma_eps_a,sigma_eps_w, sigma_z, mu_s, rho_s, rho_a, rho_w, b, chi, b_l, gamma_h, gamma_l,f, mu, p_nodes,pagg0,lambda_T,psi, sigma_x, b_max, lam_phi, beta, pref_nodes];

init_conds_ex =[s0,a0,w0];

eps_a_temp = sigma_eps_a*normrnd(0,1,T_sims,1);
eps_s_temp = sigma_eps_s*normrnd(0,1,T_sims,1);
eps_w_mat_temp = sigma_eps_w*normrnd(0,1,T_sims,num_firms);
eps_z_mat_temp  = sigma_z*normrnd(0,1,T_sims,num_firms);
lambdaT_rand_mat   = rand(T_sims, num_firms);
lambdaPhi_rand_mat = rand(T_sims, num_firms);



eps_a = NaN(T_sims,1);
eps_s = NaN(T_sims,1);
eps_w = NaN(T_sims,1);
eps_z = NaN(T_sims,1);

eps_a(1:T_sims) = eps_a_temp;
eps_s(1:T_sims) = eps_s_temp;

pmax_sims = NaN(T_sims, num_firms);
pmax_menuc_sims = NaN(T_sims, num_firms);
rmax_sims = NaN(T_sims, num_firms);

y_hist_sims = NaN(T_sims, num_firms);
n_hist_sims = NaN(T_sims, num_firms);
pjs_sims    = NaN(T_sims, num_firms);
s_sims      = NaN(T_sims, num_firms);
z_sims      = NaN(T_sims, num_firms);
a_sims      = NaN(T_sims, num_firms);
w_sims      = NaN(T_sims, num_firms);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Perform simulations
%%%
tic
parfor ii = 1:num_firms
    
    %eps_w = [eps_w_mat_temp(:,ii); NaN(100000-T_sims,1)];
    %eps_z = [eps_z_mat_temp(:,ii); NaN(100000-T_sims,1)];
    
    eps_w               = eps_w_mat_temp(:,ii);
    eps_z               = eps_z_mat_temp(:,ii);
    lambdaT_rand        = lambdaT_rand_mat(:,ii);
    lambdaPhi_rand  = lambdaPhi_rand_mat(:,ii);
    
    [rmax_sims_temp,pmax_menuc_temp,pflex_sims_temp,bound_hits,a_sims_temp,z_sims_temp,s_sims_temp,w_sims_temp,pjs_sims_temp,y_hist_temp, n_hist_temp] = sim_panel(init_conds_ex,p0,n0,y0,T_sims,eps_a,eps_s,eps_w,eps_z,lambdaT_rand,lambdaPhi_rand,z_grid, w_grid, beta_inv, w_ints, pdf_z, params);

    pmax_sims(:,ii) = rmax_sims_temp + pjs_sims_temp;
    rmax_sims(:,ii) = rmax_sims_temp;
    y_hist_sims(:,ii) = y_hist_temp;
    pjs_sims(:,ii) = pjs_sims_temp;
    n_hist_sims(:,ii) = n_hist_temp;
    
    pmax_menuc_sims(:,ii) = pmax_menuc_temp;
    
    s_sims(:,ii) = s_sims_temp;
    z_sims(:,ii) = z_sims_temp;
    a_sims(:,ii) = a_sims_temp;
    w_sims(:,ii) = w_sims_temp;
    
    if bound_hits > 0
        warning(strcat( 'Boundary hit at ', num2str(ii)))
    end
    
end
toc

%%%%%%%%%%%%%%%%%% Aggregate price and output indeces of the measure-zero ambiguity averse firms

p_agg_sims = log((b/(b-1))*chi*exp(s_sims-a_sims + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
c_agg_sims = log(((b-1)/b)*(1/chi)*exp(a_sims - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));

p_agg_sims = p_agg_sims(:,1);
c_agg_sims = c_agg_sims(:,1);

%%%%%%%%%%%%%%%%%% Price and output indeces of the measure-zero ambiguity averse firms
pjt     = 1/(1-b)*(.5*sigma_z^2+log(mean(exp((1-b)*pmax_sims),2)));
yjt     = c_agg_sims + b*(p_agg_sims - pjt); 

save( 'replication.mat', 'yjt', 'pjt', 'eps_s','T_sims_mpirf', 'num_firms_mpirf','burn_in_mpirf', 'irf_periods', '-append'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Length of simulation
T_sims    =  T_sims_mpirf;
num_firms =  num_firms_mpirf;
burn_in   =  burn_in_mpirf;

%%% Initial Exogenous states
s0 = mu_s;
a0 = 0;
w0 = 0;

params = [midQ,-b, sigma_eps_s, sigma_eps_a,sigma_eps_w, sigma_z, mu_s, rho_s, rho_a, rho_w, b, chi, b_l, gamma_h, gamma_l,f, mu, p_nodes,pagg0,lambda_T,psi, sigma_x, b_max, lam_phi, beta, pref_nodes];

init_conds_ex =[s0,a0,w0];

eps_a_temp = sigma_eps_a*normrnd(0,1,T_sims,1);
eps_s_temp = 0*sigma_eps_s*normrnd(0,1,T_sims,1);
eps_w_mat_temp = sigma_eps_w*normrnd(0,1,T_sims,num_firms);
eps_z_mat_temp  = sigma_z*normrnd(0,1,T_sims,num_firms);
lambdaT_rand_mat   = rand(T_sims, num_firms);
lambdaPhi_rand_mat = rand(T_sims, num_firms);



eps_a = NaN(T_sims,1);
eps_s = NaN(T_sims,1);
eps_w = NaN(T_sims,1);
eps_z = NaN(T_sims,1);

eps_a(1:T_sims) = eps_a_temp;
eps_s(1:T_sims) = eps_s_temp;

pmax_sims = NaN(T_sims, num_firms);
pmax_menuc_sims = NaN(T_sims, num_firms);
rmax_sims = NaN(T_sims, num_firms);

y_hist_sims = NaN(T_sims, num_firms);
n_hist_sims = NaN(T_sims, num_firms);
pjs_sims    = NaN(T_sims, num_firms);
s_sims      = NaN(T_sims, num_firms);
z_sims      = NaN(T_sims, num_firms);
a_sims      = NaN(T_sims, num_firms);
w_sims      = NaN(T_sims, num_firms);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Perform simulations
%%%
tic
parfor ii = 1:num_firms
    
    %eps_w = [eps_w_mat_temp(:,ii); NaN(100000-T_sims,1)];
    %eps_z = [eps_z_mat_temp(:,ii); NaN(100000-T_sims,1)];
    
    eps_w               = eps_w_mat_temp(:,ii);
    eps_z               = eps_z_mat_temp(:,ii);
    lambdaT_rand        = lambdaT_rand_mat(:,ii);
    lambdaPhi_rand  = lambdaPhi_rand_mat(:,ii);
    
    [rmax_sims_temp,pmax_menuc_temp,pflex_sims_temp,bound_hits,a_sims_temp,z_sims_temp,s_sims_temp,w_sims_temp,pjs_sims_temp,y_hist_temp, n_hist_temp] = sim_panel(init_conds_ex,p0,n0,y0,T_sims,eps_a,eps_s,eps_w,eps_z,lambdaT_rand,lambdaPhi_rand,z_grid, w_grid, beta_inv, w_ints, pdf_z, params);

    pmax_sims(:,ii) = rmax_sims_temp + pjs_sims_temp;
    rmax_sims(:,ii) = rmax_sims_temp;
    y_hist_sims(:,ii) = y_hist_temp;
    pjs_sims(:,ii) = pjs_sims_temp;
    n_hist_sims(:,ii) = n_hist_temp;
    
    pmax_menuc_sims(:,ii) = pmax_menuc_temp;
    
    s_sims(:,ii) = s_sims_temp;
    z_sims(:,ii) = z_sims_temp;
    a_sims(:,ii) = a_sims_temp;
    w_sims(:,ii) = w_sims_temp;
    
    if bound_hits > 0
        warning(strcat( 'Boundary hit at ', num2str(ii)))
    end
    
end
toc

%%%%%%%%%%%%%%%%%% Aggregate price and output indeces of the measure-zero ambiguity averse firms

p_agg_sims0 = log((b/(b-1))*chi*exp(s_sims-a_sims + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
c_agg_sims0 = log(((b-1)/b)*(1/chi)*exp(a_sims - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));

p_agg_sims0 = p_agg_sims0(:,1);
c_agg_sims0 = c_agg_sims0(:,1);


%%%%%%%%%%%%%%%%%% Price and output indeces of the measure-zero ambiguity averse firms
pjt0     = 1/(1-b)*(.5*sigma_z^2+log(mean(exp((1-b)*pmax_sims),2)));
yjt0     = c_agg_sims0 + b*(p_agg_sims0 - pjt0); 

save( 'replication.mat', 'yjt0', 'pjt0','-append'); 


mp_irf_amb = mp_irf( yjt, yjt0, burn_in, irf_periods,b, eps_s);

save( 'replication.mat', 'mp_irf_amb','-append'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%       2) Simulate panels of firms, prices and quantities of alternative models: 
%                                           i) Calvo, ii) menu cost, iii) Kimball Demand + menu cost 

rng('default')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Length of simulation
T_sims    =  T_sims_mpirf;
num_firms =  num_firms_mpirf;
burn_in   =  burn_in_mpirf;

%%% Initial Exogenous states
s0 = mu_s;
a0 = 0;
w0 = 0;

params = [midQ,-b, sigma_eps_s, sigma_eps_a,sigma_eps_w, sigma_z, mu_s, rho_s, rho_a, rho_w, b, chi, b_l, gamma_h, gamma_l,f, mu, p_nodes,pagg0,lambda_T,psi, sigma_x, b_max, lam_phi, beta, pref_nodes];

init_conds_ex =[s0,a0,w0];

eps_a_temp = sigma_eps_a*normrnd(0,1,T_sims,1);
eps_s_temp = sigma_eps_s*normrnd(0,1,T_sims,1);            
eps_w_mat_temp = sigma_eps_w*normrnd(0,1,T_sims,num_firms);
eps_z_mat_temp  = sigma_z*normrnd(0,1,T_sims,num_firms);
lambdaT_rand_mat   = rand(T_sims, num_firms);
lambdaPhi_rand_mat = rand(T_sims, num_firms);

eps_a(1:T_sims) = eps_a_temp;
eps_s(1:T_sims) = eps_s_temp;

T_sims = T_sims - burn_in; 


%%%%% Calibrating to frequency of regular price changes


calvo_freq            = 0.105; 
menuc_threshold       = 0.0214;           % menu cost    -- i) use 0.0214 to match frequency of regular price changes
                                          %              -- ii) use 0.049 to match frequency of modal price changes               
                                          

veps               =  10;                 % Super-elasticity of demand
kb_menuc_threshold =   0.0087;            % menu cost for Kimball model -- i) use 0.0087  to match frequency of regular price changes
                                          %                             -- ii) use 0.0217 to match frequency of modal price changes   

run_main_mpaltmodels

mp_irf_calvo_regdp = mp_irf( yjt_calvo, yjt_calvo0, burn_in, irf_periods,b, eps_s);
mp_irf_menuc_regdp = mp_irf( yjt_menuc, yjt_menuc0, burn_in, irf_periods,b, eps_s);
mp_irf_kimball_regdp = mp_irf( yjt_kimball, yjt_kimball0, burn_in, irf_periods,b, eps_s);

save( 'replication.mat', 'mp_irf_calvo_regdp', 'mp_irf_menuc_regdp','mp_irf_kimball_regdp','-append'); 

calvo_freq            = 0.026; 
menuc_threshold       = 0.049;    % menu cost    -- i) use 0.0214 to match frequency of regular price changes
                                          %              -- ii) use 0.049 to match frequency of modal price changes               
                                          

veps               =  10;                 % Super-elasticity of demand
kb_menuc_threshold =  0.0217;   % menu cost for Kimball model -- i) use 0.0087  to match frequency of regular price changes
                                          %                             -- ii) use 0.0217 to match frequency of modal price changes   

run_main_mpaltmodels

mp_irf_calvo_moddp = mp_irf( yjt_calvo, yjt_calvo0, burn_in, irf_periods,b, eps_s);
mp_irf_menuc_moddp = mp_irf( yjt_menuc, yjt_menuc0, burn_in, irf_periods,b, eps_s);
mp_irf_kimball_moddp = mp_irf( yjt_kimball, yjt_kimball0, burn_in, irf_periods,b, eps_s);


save( 'replication.mat', 'mp_irf_calvo_moddp', 'mp_irf_menuc_moddp','mp_irf_kimball_moddp','-append'); 




