%%%%
%%%% Simulates a time-series of prices for ambiguity, flexible and menu
%%%% cost firms.
%%%% Version 2: Uses separate r and p grids. r grid for ambiguity firm, p
%%%% grid for menu cost

function [rmax_sims,pmax_menuc_sims,pflex_sims,bound_hits,a_sims,z_sims,s_sims,w_sims,pjs_sims,y_hist_sims, n_hist_sims, radj_ind] = sim_panel(init_conds_ex,p0,n0,y0,T_sims,eps_a,eps_s,eps_w,eps_z,lambdaT_rand,lambdaPhi_rand,z_grid, w_grid, beta_inv, w_ints, pdf_z, params)

%%
%%% Setting parameters
midQ = params(1);
b_h  = params(2);
sigma_eps_s = params(3);
sigma_eps_a = params(4);
sigma_eps_w = params(5);
sigma_z     = params(6);
mu_s        = params(7);
rho_s       = params(8);
rho_a       = params(9);
rho_w       = params(10);
b           = params(11);
chi         = params(12);
b_l         = params(13);
gamma_h     = params(14);
gamma_l     = params(15);
f           = params(16);
mu          = params(17);
r_nodes     = params(18);
pjs0        = params(19);
lambda_T    = params(20);
psi         = params(21);
sigma_x     = params(22);
b_max       = params(23);
lam_phi     = params(24);
beta        = params(25);


%%%% Initial conditions
s0 = init_conds_ex(1);
a0 = init_conds_ex(2);
w0 = init_conds_ex(3);

sigma_w = sqrt(sigma_eps_w^2/(1-rho_w^2));

rlower_bound_adj = 10;
rupper_bound_adj = 10;
plower_bound_adj = 6;
pupper_bound_adj = 6;

T = 1/lambda_T;
temp = sqrt(ceil(T/2)*sigma_eps_s^2 + sigma_eps_a^2*(1- rho_a^(2*ceil(T/2)))/(1-rho_a^2) + sigma_w^2);

r_grid = linspace( min( 0*ceil(T/2)*mu_s - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2) - rlower_bound_adj*temp, -1), ...
    max( 0*ceil(T/2)*mu_s - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2) + rupper_bound_adj*temp, 1), r_nodes);


r = sort([r_grid,(p0-pjs0)']);
r_step = r(2) - r(1);
step_size = 0.02;

if abs(r_step) > step_size
    r_nodes = (ceil(abs(r_step)/step_size)*length(r_grid));
    r_grid = linspace( 0*ceil(T/2)*mu_s - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2) - rlower_bound_adj*temp, ...
        0*ceil(T/2)*mu_s - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2) + rupper_bound_adj*temp, r_nodes);
    
    r = sort([r_grid,(p0-pjs0)']);
    
end

p_grid = linspace( log(mu*chi) + (s0-a0 - w0) - plower_bound_adj*log(mu*chi), ...
    log(mu*chi) + (s0-a0 - w0) + pupper_bound_adj*log(mu*chi), r_nodes)';
p = sort([p_grid;p0])';

s_sims = NaN(T_sims,1);
a_sims = NaN(T_sims,1);
w_sims = NaN(T_sims,1);

p_agg_sims = NaN(T_sims,1);
c_agg_sims = NaN(T_sims,1);
pjs_sims   = NaN(T_sims,1);

gmax_sims     = NaN(T_sims,1);
rmax_sims     = NaN(T_sims,1);

pflex_sims = NaN(T_sims,1);

r_hist_sims = NaN(T_sims + length(p0),1);
y_hist_sims = NaN(T_sims + length(p0),1);
n_hist_sims = NaN(T_sims + length(p0),1);

r_hist_sims(1:length(p0)) = p0 - pjs0;
y_hist_sims(1:length(y0)) = y0;
n_hist_sims(1:length(n0)) = n0;

rmin_count = 0;
rmax_count = 0;
pmin_count_menuc = 0;
pmax_count_menuc = 0;

%%% Shocks and exogenous variables
z_sims  = eps_z;

s_sims(1) = mu_s + rho_s*s0 + eps_s(1);
a_sims(1) = rho_a*a0 + eps_a(1);
w_sims(1) = rho_w*w0 + eps_w(1);

%%% First loop iteration
t=1;

p0_length = length(p0);
r_hist = NaN(100,1);
y_hist = NaN(100,1);
n_hist = NaN(100,1);

r_hist(1:p0_length) = r_hist_sims(1:p0_length);
y_hist(1:p0_length) = y_hist_sims(1:p0_length);
n_hist(1:p0_length) = n_hist_sims(1:p0_length);

%%% Aggregates
p_agg_sims(t) = log((b/(b-1))*chi*exp(s_sims(t)-a_sims(t) + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
c_agg_sims(t) = log(((b-1)/b)*(1/chi)*exp(a_sims(t) - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
%pjs_sims(t) = pjs0;
pjs_sims(t)     = p_agg_sims(t); 

%data  = sortrows([r_hist y_hist n_hist]); %sorted data for price and quantity
r_hist_temp = r_hist(1:p0_length);
y_hist_temp = y_hist(1:p0_length);
n_hist_temp = n_hist(1:p0_length);

[~,sort_ind]  = sort(r_hist_temp);
data  = [r_hist_temp(sort_ind), y_hist_temp(sort_ind), n_hist_temp(sort_ind)];

unique_p  = unique(data(:,1));
data_unique = NaN(length(unique_p),3);

for i=1:length(unique_p)
    datat = data(data(:,1)==unique_p(i,1),:);
    nt    = sum(datat(:,3));
    avt   = sum(datat(:,2).*datat(:,3))/nt;
    data_unique(i,:) = [datat(1) avt nt];
end

r_hist(1:length(unique_p)) = data_unique(:,1);
y_hist(1:length(unique_p)) = data_unique(:,2);
n_hist(1:length(unique_p)) = data_unique(:,3);

r_hist_temp = r_hist(1:length(unique_p));
y_hist_temp = y_hist(1:length(unique_p));
n_hist_temp = n_hist(1:length(unique_p));

r_counter = length(unique_p);

%%% Expected Demand
GPupdate_fun = @(x) GPupdate_slr_v3(x, r,gamma_h,b_h,gamma_l,b_l,sigma_z,psi,sigma_x,r, b_max);

[qDemand, sigmaxsqr_hat] = GPupdate_fun( [r_hist_temp,y_hist_temp,n_hist_temp]);

%%%%% Initializing things specific to forward looking behavior
pref_nodes = length(r);
qref_nodes = length(z_grid);
w_nodes    = length(w_grid);
pref_grid  = r;

exp_pagg   = log((b/(b-1))*chi) + rho_s*s_sims(t) + mu_s - rho_a*a_sims(t) + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2);
exp_cagg   = - log((b/(b-1))*chi) + rho_a*a_sims(t) - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2);

params_CV = [ pref_nodes, qref_nodes, w_nodes, sigma_z, psi, sigma_x, b, pjs_sims(t), exp_pagg, exp_cagg, mu_s + rho_s*s_sims(t), rho_a*a_sims(t), chi];

recompute_VF = 1;

if recompute_VF == 1
    VF_mat = cont_value_fun_fast( pref_grid, z_grid, w_grid,r, r_hist, n_hist, qDemand, beta_inv, params_CV, r_counter, sigmaxsqr_hat);
end

pdf_w_temp = NaN(1, w_nodes);

pdf_w_temp(1)       = normcdf( w_ints(1),   rho_w*w_sims(t), sigma_eps_w);
pdf_w_temp(end)     = 1 - normcdf( w_ints(end),  rho_w*w_sims(t), sigma_eps_w);
pdf_w_temp(2:end-1) = normcdf( w_ints(2:end), rho_w*w_sims(t), sigma_eps_w) - normcdf( w_ints(1 :end-1), rho_w*w_sims(t), sigma_eps_w);

EV = NaN(pref_nodes,1);
pdf_zw_cond = pdf_z*pdf_w_temp;

for i_p1 = 1:pref_nodes
    
    VF_temp = VF_mat(:, :,i_p1);
    EV(i_p1) = sum(sum(VF_temp.*pdf_zw_cond));
    
end

%%% Ambiguity averse firm's problem
g = ((exp(r + pjs_sims(t))/exp(p_agg_sims(t)))-chi*exp(s_sims(t))/(exp(p_agg_sims(t) + a_sims(t) + w_sims(t)))).*exp(0.5*(sigma_z^2 + sigmaxsqr_hat) + b*(p_agg_sims(t) - pjs_sims(t)) + c_agg_sims(t) + qDemand); %%% Calculates the profit function at each point in the price grid.
G1 = g + beta*EV';   %%% Objective function at time 1

[g_max_iter, rmax_ind_iter] = max(G1);

rmin_count = rmin_count + (rmax_ind_iter == 1);
rmax_count = rmax_count + (rmax_ind_iter == length(r));

gmax_sims(t) = g_max_iter;
rmax_sims(t) = r(rmax_ind_iter);

r_hist_sims(length(p0) + t) = rmax_sims(t);
y_hist_sims(length(p0) + t) = midQ - b*(rmax_sims(t) - (p_agg_sims(t) - pjs_sims(t))  ) + z_sims(t);
n_hist_sims(1: length(p0) + t-1) = n_hist_sims(1: length(p0) + t-1);
n_hist_sims(length(p0) + t) = 1;

r_ind = find( rmax_sims(t) == r_hist_temp);

if isempty(r_ind)
    r_hist(r_counter+1) =  rmax_sims(t);
    y_hist(r_counter+1) =  midQ - b*(rmax_sims(t) - (p_agg_sims(t) - pjs_sims(t))  ) + z_sims(t);
    n_hist(r_counter+1) = 1;
    
    y_hist_temp = y_hist(1:r_counter+1);
    n_hist_temp = n_hist(1:r_counter+1);
    
    [r_hist_temp,sort_ind]  = sort(r_hist(1:r_counter+1));
    
    r_hist(1:r_counter+1) = r_hist_temp;
    y_hist(1:r_counter+1) = y_hist_temp(sort_ind);
    n_hist(1:r_counter+1) = n_hist_temp(sort_ind);
    
    y_hist_temp = y_hist(1:r_counter+1);
    n_hist_temp = n_hist(1:r_counter+1);
    
    r_counter = r_counter + 1; 
    
else
    y_hist(r_ind) = ( n_hist(r_ind)*y_hist(r_ind) +  ( midQ - b*(rmax_sims(t) - (p_agg_sims(t) - pjs_sims(t))  ) + z_sims(t) ) )/(n_hist(r_ind) + 1);
    n_hist(r_ind) = n_hist(r_ind) + 1;
    
    y_hist_temp(r_ind) = y_hist(r_ind);
    n_hist_temp(r_ind) = n_hist(r_ind);
end

%%% Menu cost problem
pchange_ind = (p ~= p0(end));
qDemand_re = (midQ- b*p);  %%% Rational expectations + full information
g_menuc= ((exp(p)/exp(p_agg_sims(t)))-chi*exp(s_sims(t))/(exp(p_agg_sims(t) + a_sims(t) + w_sims(t)))).*exp(0.5*sigma_z^2 + b*p_agg_sims(t) + c_agg_sims(t) + qDemand_re) - pchange_ind*f*chi*exp(c_agg_sims(t));
[gmax_menuc_iter, pmax_ind_menuc_iter] = max(g_menuc);

pmin_count_menuc = pmin_count_menuc + (pmax_ind_menuc_iter == 1);
pmax_count_menuc = pmax_count_menuc + (pmax_ind_menuc_iter == length(r));

gmax_menuc_sims(t) = gmax_menuc_iter;
pmax_menuc_sims(t) = p(pmax_ind_menuc_iter);


radj_ind = 0;

for t = 2:T_sims
    
   
    s_sims(t) = mu_s + rho_s*s_sims(t-1) + eps_s(t);
    a_sims(t) = rho_a*a_sims(t-1) + eps_a(t);
    w_sims(t) = rho_w*w_sims(t-1) + eps_w(t);
    
    
    %%% Aggregates
    p_agg_sims(t) = log((b/(b-1))*chi*exp(s_sims(t)-a_sims(t) + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
    c_agg_sims(t) = log(((b-1)/b)*(1/chi)*exp(a_sims(t) - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2)));
    
    price_reg  = lambdaT_rand(t);
    pjs_sims(t)   =  ( price_reg < lambda_T)*p_agg_sims(t) + ( price_reg >= lambda_T )*pjs_sims(t-1);
    
    reset_ind = lambdaPhi_rand(t);
    if reset_ind  <= lam_phi
        r_hist = NaN(100,1);
        y_hist = NaN(100,1);
        n_hist = NaN(100,1);
        
        r_hist(1) = p0;
        y_hist(1) = y0;
        n_hist(1) = n0;
        pjs_sims(t)   =  p_agg_sims(t);
        
        r_hist_temp = p0;
        y_hist_temp = y0;
        n_hist_temp = n0;
        
        w_sims(t) = eps_w(t); %/sqrt(1 - rho_w^2); 
        
        r_counter = 1; 
        
        %%%%%% Start off the new firms with same continuation value as the initial firms
        recompute_VF = 1; 
    end
    
   
    
    %%% Expected Demand
    
    [qDemand, sigmaxsqr_hat] = GPupdate_fun( [r_hist_temp,y_hist_temp,n_hist_temp]);
    
    %%%%% Initializing things specific to forward looking behavior
    
    
    pref_nodes = length(r);
    qref_nodes = length(z_grid);
    w_nodes    = length(w_grid);
    pref_grid  = r;
    
    exp_pagg   = log((b/(b-1))*chi) + rho_s*s_sims(t) + mu_s - rho_a*a_sims(t) + 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2);
    exp_cagg   = - log((b/(b-1))*chi) + rho_a*a_sims(t) - 0.5*(sigma_z^2/(1-b) + (1-b)*sigma_w^2);
    
    params_CV = [ pref_nodes, qref_nodes, w_nodes, sigma_z, psi, sigma_x, b, pjs_sims(t), exp_pagg, exp_cagg, mu_s + rho_s*s_sims(t), rho_a*a_sims(t), chi];
    
    
    if recompute_VF == 1
        VF_mat = cont_value_fun_fast( pref_grid, z_grid, w_grid,r, r_hist, n_hist, qDemand, beta_inv, params_CV, r_counter, sigmaxsqr_hat);
    end
    
    pdf_w_temp = NaN(1, w_nodes);
    
    pdf_w_temp(1)       = normcdf( w_ints(1),   rho_w*w_sims(t), sigma_eps_w);
    pdf_w_temp(end)     = 1 - normcdf( w_ints(end),  rho_w*w_sims(t), sigma_eps_w);
    pdf_w_temp(2:end-1) = normcdf( w_ints(2:end), rho_w*w_sims(t), sigma_eps_w) - normcdf( w_ints(1 :end-1), rho_w*w_sims(t), sigma_eps_w);
    
    EV = NaN(pref_nodes,1);
    pdf_zw_cond = pdf_z*pdf_w_temp;
    
    for i_p1 = 1:pref_nodes
        
        VF_temp = VF_mat(:, :,i_p1);
        EV(i_p1) = sum(sum(VF_temp.*pdf_zw_cond));
        
    end
    
    %%% Ambiguity averse firm's problem
    g = ((exp(r + pjs_sims(t))/exp(p_agg_sims(t)))-chi*exp(s_sims(t))/(exp(p_agg_sims(t) + a_sims(t) + w_sims(t)))).*exp(0.5*(sigma_z^2 + sigmaxsqr_hat) + b*(p_agg_sims(t) - pjs_sims(t)) + c_agg_sims(t) + qDemand); %%% Calculates the profit function at each point in the price grid.
    G1 = g + beta*EV';   %%% Objective function at time 1
    
    [g_max_iter, rmax_ind_iter] = max(G1);
    
    rmin_count = rmin_count + (rmax_ind_iter == 1);
    rmax_count = rmax_count + (rmax_ind_iter == length(r));
    
    gmax_sims(t) = g_max_iter;
    rmax_sims(t) = r(rmax_ind_iter);
    
    r_hist_sims(length(p0) + t) = rmax_sims(t);
    y_hist_sims(length(p0) + t) = midQ - b*( rmax_sims(t) - (p_agg_sims(t) - pjs_sims(t))  ) + z_sims(t);
    n_hist_sims(1: length(p0) + t-1) = n_hist_sims(1: length(p0) + t-1);
    n_hist_sims(length(p0) + t) = 1;
    
    r_ind = find( rmax_sims(t) == r_hist);
    
    if isempty(r_ind)
        r_hist(r_counter+1) =  rmax_sims(t);
        y_hist(r_counter+1) =  midQ - b*(rmax_sims(t) - (p_agg_sims(t) - pjs_sims(t))  ) + z_sims(t);
        n_hist(r_counter+1) = 1;
        
        y_hist_temp = y_hist(1:r_counter+1);
        n_hist_temp = n_hist(1:r_counter+1);
        
        [r_hist_temp,sort_ind]  = sort(r_hist(1:r_counter+1));
        
        r_hist(1:r_counter+1) = r_hist_temp;
        y_hist(1:r_counter+1) = y_hist_temp(sort_ind);
        n_hist(1:r_counter+1) = n_hist_temp(sort_ind);
        
        y_hist_temp = y_hist(1:r_counter+1);
        n_hist_temp = n_hist(1:r_counter+1);
        
        recompute_VF = 1;
        
        r_counter = r_counter + 1; 

    else
        y_hist(r_ind) = ( n_hist(r_ind)*y_hist(r_ind) +  ( midQ - b*(rmax_sims(t) - (p_agg_sims(t) - pjs_sims(t))  ) + z_sims(t) ) )/(n_hist(r_ind) + 1);
        n_hist(r_ind) = n_hist(r_ind) + 1;
        
        y_hist_temp(r_ind) = y_hist(r_ind);
        n_hist_temp(r_ind) = n_hist(r_ind);
        
        if n_hist(r_ind) > 10
            recompute_VF = 0;
        else
            recompute_VF = 1;
        end
        
        
    end
   
    %%% Menu cost problem
    pchange_ind = (p ~= pmax_menuc_sims(t-1));
    
    g_menuc= ((exp(p)/exp(p_agg_sims(t)))-chi*exp(s_sims(t))/(exp(p_agg_sims(t) + a_sims(t) + w_sims(t)))).*exp(0.5*sigma_z^2 + b*p_agg_sims(t) + c_agg_sims(t) + qDemand_re) - pchange_ind*f*chi*exp(c_agg_sims(t));
    [gmax_menuc_iter, pmax_ind_menuc_iter] = max(g_menuc);
    
    pmin_count_menuc = pmin_count_menuc + (pmax_ind_menuc_iter == 1);
    pmax_count_menuc = pmax_count_menuc + (pmax_ind_menuc_iter == length(r));
    
    gmax_menuc_sims(t) = gmax_menuc_iter;
    pmax_menuc_sims(t) = p(pmax_ind_menuc_iter);
    
end

y_hist_sims = y_hist_sims(1+length(p0):end);
n_hist_sims = n_hist_sims(1+length(p0):end);

bound_hits = max([rmax_count,rmin_count]);

end